<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Cryptlight_Elementor_Author_Box extends Widget_Base {

	
	public function get_name() {
		return 'cryptlight_elementor_author_box';
	}

	
	public function get_title() {
		return esc_html__( 'Author Box', 'cryptlight' );
	}

	
	public function get_icon() {
		return 'eicon-lock-user';
	}

	
	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'cryptlight' ),
			]
		);	
			
		// Add Class control

		    $this->add_control(
				'description',
				[
					'label' 	=> esc_html__( 'Description', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__( '"50% of all sales will go directly towards projects for poor artists around the world who have a burning passion for art, so we need support of all you."', 'cryptlight' ),
				]
			);

		    $this->add_control(
				'image',
				[
					'label' 	=> esc_html__( 'Image Author', 'cryptlight' ),
					'type' 		=> Controls_Manager::MEDIA,
					'dynamic' 	=> [
						'active' 	=> true,
					],
					'default' 	=> [
						'url' 	=> Utils::get_placeholder_image_src(),
					],
				]
			);
				
			$this->add_control(
				'name',
				[
					'label' 	=> esc_html__( 'Name', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'Esther Howard', 'cryptlight' ),
				]
			);

			$this->add_control(
				'job',
				[
					'label' 	=> esc_html__( 'Job', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( '_CEO', 'cryptlight' ),
				]
			);
            
			// list icons control
			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'class_icon',
				[
					'label' 	=> esc_html__( 'Class Icon', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=>  esc_html__( 'ovaicon-twitter', 'cryptlight' ),
					
				]
			);
			 
			$repeater->add_control(
				'link',
				[
					'label' 	=> esc_html__( 'Link', 'cryptlight' ),
					'type' 		=> Controls_Manager::URL,
					'default' 	=> [
						'url' => '#',
						'is_external' => 'on',
					],
					'dynamic' => [
						'active' => true,
					],
					'placeholder' => esc_html__( 'https://your-link.com', 'cryptlight' ),
				]
			);

			$repeater->add_control(
				'list_title_icon', [
					'label' 		=> esc_html__( 'Title Icon', 'cryptlight' ),
					'type' 			=> Controls_Manager::TEXT,
					'default' 		=> esc_html__( 'List Title Icon' , 'cryptlight' ),
					'label_block' 	=> true,
				]
			);
			
            $this->add_control(
				'icons',
				[
					'label' 	=> esc_html__( 'Social Icons', 'cryptlight' ),
					'type' 		=> Controls_Manager::REPEATER,
					'fields' 	=> $repeater->get_controls(),
					'default' 	=> [
						[	
							'list_title_icon' 	=> esc_html__( 'Twitter', 'cryptlight' ),
							'class_icon' 		=> esc_html__( 'ovaicon-twitter', 'cryptlight' ),
							'link' 				=> ['url' => '#'],
						],
						[	
							'list_title_icon' 	=> esc_html__( 'Linkedin', 'cryptlight' ),
							'class_icon' 		=> esc_html__( 'fab fa-linkedin-in', 'cryptlight' ),
							'link' 				=> ['url' => '#'],
						],
						[	
							'list_title_icon' 	=> esc_html__( 'Facebook', 'cryptlight' ),
							'class_icon' 		=> esc_html__( 'ovaicon-facebook-logo-1', 'cryptlight' ),
							'link' 				=> ['url' => '#'],
						],
	
					],
					'title_field' => '{{{ list_title_icon }}}',
				]
			);

		$this->end_controls_section();
        
        // Tabs style

        /* Begin Description Style */
		$this->start_controls_section(
            'description_style',
            [
                'label' => esc_html__( 'Description', 'cryptlight' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'description_typography',
					'selector' 	=> '{{WRAPPER}} .ova-author-box .description',
				]
			);

			$this->add_control(
				'color_description',
				[
					'label' 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-author-box .description' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'description_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-author-box .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
        /* End Description Style */

        $this->start_controls_section(
			'section_style_icon',
			[
				'label' 	=> esc_html__( 'Icons', 'cryptlight' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->start_controls_tabs( 'tabs_icon_style' );

				$this->start_controls_tab(
					'icon_normal',
					[
						'label' => esc_html__( 'Normal', 'cryptlight' ),
					]
				);

					$this->add_control(
						'color_icon',
						[
							'label' 	=> esc_html__( 'Color', 'cryptlight' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .list-icon ul .item i' => 'color : {{VALUE}};',
							],
						]
					);

                    $this->add_control(
						'background_color_icon',
						[
							'label' 	=> esc_html__( 'Background Color', 'cryptlight' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .list-icon ul .item a' => 'background-color : {{VALUE}};',
							],
							
						]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
					'icon_hover',
					[
						'label' => esc_html__( 'Hover', 'cryptlight' ),
					]
				);

					$this->add_control(
						'color_social_icons_hover',
						[
							'label' 	=> esc_html__( 'Color', 'cryptlight' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-author-box .list-icon .item i:hover' => 'color : {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'bg_color_social_icons_hover',
						[
							'label' 	=> esc_html__( 'Background Color', 'cryptlight' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .list-icon ul .item:hover a' => 'background-color : {{VALUE}};',
							],
						]
					);

                $this->end_controls_tab();
			$this->end_controls_tabs();

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_info',
			[
				'label' 	=> esc_html__( 'Info', 'cryptlight' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_responsive_control(
	            'info_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-author-box .info-img .info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'info_border',
					'label' => esc_html__( 'Border', 'cryptlight' ),
					'selector' => '{{WRAPPER}} .ova-author-box .info-img .info',
				]
			);

            $this->add_control(
				'heading_name',
				[
					'label' 	=> esc_html__( 'Name', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before'
				]
			);

		    $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'name_typography',
					'selector' 	=> '{{WRAPPER}} .ova-author-box .info-img .info .name',
				]
			);

			$this->add_control(
				'color_name',
				[
					'label' 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-author-box .info-img .info .name' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_name_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-author-box .info-img .info .name:hover' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'name_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-author-box .info-img .info .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

			$this->add_control(
				'heading_job',
				[
					'label' 	=> esc_html__( 'Job', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before'
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'job_typography',
					'selector' 	=> '{{WRAPPER}} .ova-author-box .info-img .info .job',
				]
			);


			$this->add_control(
				'color_job',
				[
					'label' => esc_html__( 'Color', 'cryptlight' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-author-box .info-img .info .job' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'heading_rectangle',
				[
					'label' 	=> esc_html__( 'Rectangle', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before'
				]
			);

			$this->add_control(
				'color_rectangle',
				[
					'label' 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-author-box .info-img:before' => 'background-color : {{VALUE}};',
					],
				]
			);

		$this->end_controls_section();
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		 // Get url image
		$url 	= $settings['image']['url'];
		$alt 	= isset( $settings['image']['alt'] ) ? $settings['image']['alt'] : '';
		
		if ( empty( $url ) ) {
			return;
		}

		// Get description
		$description  = $settings['description'];
		// Get name
		$name 		  = $settings['name'];
		// Get job
		$job 	      = $settings['job'];

		if ( empty( $alt ) ) {
			$alt = $name ? $name : esc_html__( 'Avatar', 'cryptlight' );
		}

        // list social icons
		$icons 		= $settings['icons'];

		 ?>

			<div class="ova-author-box">
				<?php if ( ! empty ( $description ) ): ?>
					<div  class="description">
						<?php echo esc_html( $description ); ?>
					</div>
				<?php endif; ?>

				<div class="info-img">
					
					<img src="<?php echo esc_url( $url ); ?>" class="author-img" alt="<?php echo esc_attr( $alt ); ?>">
					

					<div class="info">
						<?php if ( ! empty ( $name ) ): ?>
							<h2 class="name"><?php echo esc_html($name); ?></h2>
						<?php endif; ?>

						<?php if ( ! empty ( $job ) ): ?>
						<p  class="job">
							<?php echo esc_html( $job ); ?>
						</p>
						<?php endif; ?>
					</div>
				</div>

				<div class="list-icon" >
					<?php if ( !empty( $icons ) ) : ?>
						<ul>
							<?php 
							foreach( $icons as $icon ) { 

								$link = $icon['link']['url'];
								$is_external = $icon['link']['is_external'];
								$target = ( $is_external == 'on' ) ? ' target="_blank"' : '';

								?>
								<li class="item">
									<?php if ( ! empty( $link ) ): ?>
										<a href="<?php echo esc_url( $link );?>"<?php echo esc_attr( $target ); ?>>
											<i class="<?php echo esc_attr( $icon['class_icon'] ); ?>"></i>
										</a>
									<?php endif; ?>
								</li>
							<?php } ?>
						</ul>
					<?php endif; ?>
				</div>
			</div>

		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Author_Box() );