<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cryptlight_Elementor_Heading_2 extends Widget_Base {

	public function get_name() {
		return 'cryptlight_elementor_heading_2';
	}

	public function get_title() {
		return esc_html__( 'Ova Heading 2', 'cryptlight' );
	}

	public function get_icon() {
		return 'eicon-t-letter';
	}

	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'cryptlight' ),
			]
		);	

			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'cryptlight' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'template1',
					'options' => [
						'template1' => esc_html__('Template 1', 'cryptlight'),
						'template2' => esc_html__('Template 2', 'cryptlight'),
						'template3' => esc_html__('Template 3', 'cryptlight'),
					]
				]
			);

			$this->add_control(
				'prefix',
				[
					'label' => esc_html__( 'Prefix', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			
			$this->add_control(
				'sub_title',
				[
					'label' => esc_html__( 'Sub Title', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'default' => esc_html__( 'Sub Title', 'cryptlight' ),
				]
			);

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'default' => esc_html__( "Let's Enjoy Cryptlight Theme.", 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your title here', 'cryptlight' ),
				]
			);

			$this->add_control(
				'title_feature_image',
				[
					'label' => esc_html__( 'Feature Image', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
					'condition' => [
						'show_image' => 'yes',
					],
				]
			);

			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'cryptlight' ),
					'options' => [ 'url', 'is_external', 'nofollow' ],
					'default' => [
						'url' => '',
						'is_external' => false,
						'nofollow' => false,
					],
				]
			);

			$this->add_control(
				'html_tag',
				[
					'label' => esc_html__( 'HTML Tag', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'h2',
					'options' => [
						'h1' => esc_html__( 'H1', 'cryptlight' ),
						'h2' => esc_html__( 'H2', 'cryptlight' ),
						'h3' => esc_html__( 'H3', 'cryptlight' ),
						'h4' => esc_html__( 'H4', 'cryptlight' ),
						'h5' => esc_html__( 'H5', 'cryptlight' ),
						'h6' => esc_html__( 'H6', 'cryptlight' ),
						'div' => esc_html__( 'div', 'cryptlight' ),
						'span' => esc_html__( 'span', 'cryptlight' ),
						'p' => esc_html__( 'p', 'cryptlight' ),
					],
				]
			);	

			$this->add_control(
				'description',
				[
					'label' => esc_html__( 'Description', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'placeholder' => esc_html__( 'Type your description here', 'cryptlight' ),
				]
			);

			$this->add_responsive_control(
				'alignment',
				[
					'label' => esc_html__( 'Alignment', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => esc_html__( 'Left', 'cryptlight' ),
							'icon' => 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'cryptlight' ),
							'icon' => 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'cryptlight' ),
							'icon' => 'eicon-text-align-right',
						],
					],
					'toggle' => true,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2' => 'text-align: {{VALUE}};',
					],
					'condition' => [
						'template!' => 'template3',
					],
				]
			);

			$this->add_control(
				'show_author',
				[
					'label' 		=> esc_html__( 'Show Author', 'cryptlight' ),
					'type' 			=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 		=> esc_html__( 'Show', 'cryptlight' ),
					'label_off' 	=> esc_html__( 'Hide', 'cryptlight' ),
					'return_value' 	=> 'yes',
					'default' 		=> 'no',
					'condition' => [
						'template' => 'template1',
					],
				],
			);

			$this->add_control(
				'author_prefix',
				[
					'label' => esc_html__( 'Prefix', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( '*', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type author prefix here', 'cryptlight' ),
					'condition' => [
						'template' => 'template1',
						'show_author' => 'yes',
					],
				]
			);

			$this->add_control(
				'author',
				[
					'label' => esc_html__( 'Author', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Ceo & Founder - Bellal Dhar', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your title here', 'cryptlight' ),
					'condition' => [
						'template' => 'template1',
						'show_author' => 'yes',
					],
				]
			);

			$this->add_control(
				'show_button_booking',
				[
					'label' 		=> esc_html__( 'Show Button', 'cryptlight' ),
					'type' 			=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 		=> esc_html__( 'Show', 'cryptlight' ),
					'label_off' 	=> esc_html__( 'Hide', 'cryptlight' ),
					'return_value' 	=> 'yes',
					'default' 		=> 'yes',
					'condition' => [
						'template' => 'template3',
					],
				],
			);

			$this->add_control(
				'text_booking',
				[
					'label' => esc_html__( 'Text Button', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Join now', 'cryptlight' ),
					'condition' => [
						'template' => 'template3',
						'show_button_booking' => 'yes',
					],
				]
			);

			$this->add_control(
				'link_booking',
				[
					'label' => esc_html__( 'Link', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'cryptlight' ),
					'options' => [ 'url', 'is_external', 'nofollow' ],
					'default' => [
						'url' => '#',
						'is_external' => true,
						'nofollow' => false,
					],
					'condition' => [
						'template' => 'template3',
						'show_button_booking' => 'yes',
					],
				]
			);

		$this->end_controls_section();

		//SECTION TAB STYLE SUB TITLE
		$this->start_controls_section(
			'section_sub_title',
			[
				'label' => esc_html__( 'Sub Title', 'cryptlight' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'sub_title_prefix_heading',
				[
					'label' => esc_html__( 'Prefix', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
				]
			);

			$this->add_responsive_control(
				'sub_title_prefix_size',
				[
					'label' => esc_html__( 'Size', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem'],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .sub-title-wrapper .prefix' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'sub_title_prefix_color',
				[
					'label'	 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .sub-title-wrapper .prefix' => 'color : {{VALUE}};'
					],
				]
			);

			$this->add_control(
				'sub_title_text_heading',
				[
					'label' => esc_html__( 'Text', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'sub_title_text_typography',
					'label' 	=> esc_html__( 'Typography', 'cryptlight' ),
					'selector' 	=> '{{WRAPPER}} .ova-heading-2 .sub-title-wrapper .sub-title',
				]
			);

			$this->add_control(
				'sub_title_text_color',
				[
					'label'	 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2  .sub-title-wrapper .sub-title' => 'color : {{VALUE}};'
					],
				]
			);

			$this->add_control(
				'sub_title_border_color',
				[
					'label'	 	=> esc_html__( 'Border Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2  .sub-title-wrapper' => 'border-color : {{VALUE}};'
					],
				]
			);

			$this->add_responsive_control(
				'sub_title_padding',
				[
					'label' 	 => esc_html__( 'Padding', 'cryptlight' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading-2  .sub-title-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'sub_title_margin',
				[
					'label' 	 => esc_html__( 'Margin', 'cryptlight' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading-2 .sub-title-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE SUB TITLE

		//SECTION TAB STYLE TITLE
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => esc_html__( 'Title', 'cryptlight' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_title',
					'label' 	=> esc_html__( 'Typography', 'cryptlight' ),
					'selector' 	=> '{{WRAPPER}} .ova-heading-2 .title',
				]
			);

			$this->add_control(
				'color_title',
				[
					'label' 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .title, {{WRAPPER}} .ova-heading-2 .title a' => 'color : {{VALUE}};',
					],
					'condition' => [
						'template!' => 'template2',
					],
				]
			);

			$this->add_control(
				'color_title_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .title:hover, {{WRAPPER}} .ova-heading-2 .title:hover a' => 'color : {{VALUE}};'
					],
					'condition' => [
						'template!' => 'template2',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'title_bgcolor',
					'types' => [ 'classic', 'gradient' ],
					'selector' => '{{WRAPPER}} .ova-heading-2 .title',
					'condition' => [
						'template' => 'template2',
					],
				]
			);

			$this->add_responsive_control( 
				'margin_title',
				[
					'label' 	 => esc_html__( 'Margin', 'cryptlight' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading-2 .title ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control( 
				'text_custom_heading',
				[
					'label' 	 => esc_html__( 'Special Text', 'cryptlight' ),
					'type' 		 => Controls_Manager::HEADING,
				]
			);

			$this->add_control(
				'special_text_custom',
				[
					'label' 		=> esc_html__( 'Show Special Text ', 'cryptlight' ),
					'type' 			=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 		=> esc_html__( 'Show', 'cryptlight' ),
					'label_off' 	=> esc_html__( 'Hide', 'cryptlight' ),
					'return_value' 	=> 'yes',
					'default' 		=> 'yes',
				]
			);

			$this->add_control(
				'word_position',
				[
					'label' => esc_html__( 'Word Position', 'cryptlight' ),
					'type'	=> \Elementor\Controls_Manager::NUMBER,
					'min' 	=> 0,
					'max' 	=> 20,
					'step' 	=> 1,
					'default' => 2,
					'condition' => [
						'special_text_custom' => 'yes',
					],
				]
			);

			$this->add_control(
				'word_position_2',
				[
					'label' => esc_html__( 'Word Position 2', 'cryptlight' ),
					'type'	=> \Elementor\Controls_Manager::NUMBER,
					'min' 	=> 0,
					'max' 	=> 20,
					'step' 	=> 1,
					'condition' => [
						'special_text_custom' => 'yes',
					],
				]
			);

			$this->add_control(
				'show_image',
				[
					'label' 		=> esc_html__( 'Show Image', 'cryptlight' ),
					'type' 			=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 		=> esc_html__( 'Show', 'cryptlight' ),
					'label_off' 	=> esc_html__( 'Hide', 'cryptlight' ),
					'return_value' 	=> 'yes',
					'default' 		=> 'yes',
					'condition' => [
						'special_text_custom' => 'yes',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_title_word',
					'label' 	=> esc_html__( 'Typography', 'cryptlight' ),
					'selector' 	=> '{{WRAPPER}} .ova-heading-2 .title .word',
					'condition' => [
						'special_text_custom' => 'yes',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'special_text_bgcolor',
					'types' => [ 'classic', 'gradient' ],
					'selector' => '{{WRAPPER}} .ova-heading-2 .title .word',
					'condition' => [
						'special_text_custom' => 'yes',
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE TITLE

		//SECTION TAB STYLE DESCRIPTION
		$this->start_controls_section(
			'section_description',
			[
				'label' => esc_html__( 'Description', 'cryptlight' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_description',
					'label' 	=> esc_html__( 'Typography', 'cryptlight' ),
					'selector' 	=> '{{WRAPPER}} .ova-heading-2 .description',
				]
			);

			$this->add_control(
				'color_description',
				[
					'label'	 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .description' => 'color : {{VALUE}};'		
					],
				]
			);

			$this->add_responsive_control(
				'padding_description',
				[
					'label' 	 => esc_html__( 'Padding', 'cryptlight' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading-2 .description ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'margin_description',
				[
					'label' 	 => esc_html__( 'Margin', 'cryptlight' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading-2 .description ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'description_border',
					'selector' => '{{WRAPPER}} .ova-heading-2 .description ',
				]
			);
			
		$this->end_controls_section();
		//END SECTION TAB STYLE DESCRIPTION
		
		//SECTION TAB STYLE AUTHOR
		$this->start_controls_section(
			'section_author',
			[
				'label' => esc_html__( 'Author', 'cryptlight' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'template' => 'template1',
					'show_author' => 'yes',
				],
			]
		);

			$this->add_control(
				'author_divider',
				[
					'label' => esc_html__( 'Divider', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_control(
				'author_divider_width',
				[
					'label' => esc_html__( 'Width', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .author .divider' => 'width: {{SIZE}}{{UNIT}};min-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'author_divider_height',
				[
					'label' => esc_html__( 'Height', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 20,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .author .divider' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'author_divider_color',
				[
					'label'	 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .author .divider' => 'background-color : {{VALUE}};'		
					],
				]
			);

			$this->add_control(
				'author_prefix_heading',
				[
					'label' => esc_html__( 'Author Prefix', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_control(
				'author_prefix_size',
				[
					'label' => esc_html__( 'Size', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .author .author-prefix' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'author_prefix_color',
				[
					'label'	 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .author .author-prefix' => 'color : {{VALUE}};'		
					],
				]
			);

			$this->add_responsive_control(
				'author_prefix_margin',
				[
					'label' 	 => esc_html__( 'Margin', 'cryptlight' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading-2 .author .author-prefix' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'author_heading',
				[
					'label' => esc_html__( 'Author', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_author',
					'label' 	=> esc_html__( 'Typography', 'cryptlight' ),
					'selector' 	=> '{{WRAPPER}} .ova-heading-2 .author .text',
				]
			);

			$this->add_control(
				'color_author',
				[
					'label'	 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2 .author .text' => 'color : {{VALUE}};'		
					],
				]
			);

			$this->add_responsive_control(
				'author_margin',
				[
					'label' 	 => esc_html__( 'Margin', 'cryptlight' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading-2 .description ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			
		$this->end_controls_section();
		//END SECTION TAB STYLE AUTHOR
		
		//SECTION TAB STYLE BUTTON BOOKING
		$this->start_controls_section(
			'section_button_booking',
			[
				'label' => esc_html__( 'Button', 'cryptlight' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'template' => 'template3',
					'show_button_booking' => 'yes',
				],
			]
		);

			$this->add_control(
				'button_booking_width',
				[
					'label' => esc_html__( 'Width', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 300,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking' => 'width: {{SIZE}}{{UNIT}};min-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'button_booking_height',
				[
					'label' => esc_html__( 'Height', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 300,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'button_booking_background_color',
				[
					'label'	 	=> esc_html__( 'Background Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking' => 'background-color : {{VALUE}};'		
					],
				]
			);

			$this->add_control(
				'button_booking_background_color_hover',
				[
					'label'	 	=> esc_html__( 'Background Color Hover', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking:hover' => 'background-color : {{VALUE}};'		
					],
				]
			);

			$this->add_responsive_control(
				'button_booking_border_radius',
				[
					'label' 	 => esc_html__( 'Border Radius', 'cryptlight' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'button_booking_border',
					'selector' => '{{WRAPPER}} ova-heading.template3 .button-booking',
				]
			);

			$this->add_control(
				'button_booking_border_color_hover',
				[
					'label'	 	=> esc_html__( 'Border Color Hover', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking:hover' => 'border-color : {{VALUE}};'		
					],
				]
			);

			$this->add_control(
				'button_booking_text_heading',
				[
					'label' => esc_html__( 'Text', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' 		=> 'button_booking_text_typography',
					'label' 	=> esc_html__( 'Typography', 'cryptlight' ),
					'selector' 	=> '{{WRAPPER}} .ova-heading-2.template3 .button-booking .text-booking',
				]
			);

			$this->add_control(
				'button_booking_text_color',
				[
					'label'	 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking .text-booking' => 'color : {{VALUE}};'		
					],
				]
			);

			$this->add_control(
				'button_booking_text_color_hover',
				[
					'label'	 	=> esc_html__( 'Color Hover', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking:hover .text-booking' => 'color : {{VALUE}};'		
					],
				]
			);

			$this->add_responsive_control(
				'button_booking_text_margin',
				[
					'label' 	 => esc_html__( 'Margin', 'cryptlight' ),
					'type' 		 => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking .text-booking' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'button_booking_icon_heading',
				[
					'label' => esc_html__( 'Icon', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_control(
				'button_booking_icon_size',
				[
					'label' => esc_html__( 'Size', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'button_booking_icon_color',
				[
					'label'	 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking i' => 'color : {{VALUE}};'		
					],
				]
			);
	
			$this->add_control(
				'button_booking_icon_color_hover',
				[
					'label'	 	=> esc_html__( 'Color Hover', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-heading-2.template3 .button-booking:hover i' => 'color : {{VALUE}};'		
					],
				]
			);

		$this->end_controls_section();
		//END SECTION TAB STYLE AUTHOR
	}

	// Render Template Here
	protected function render() {
		$settings = $this->get_settings();

		$template 							= 	$settings['template'];
		$prefix 							= 	$settings['prefix'];
		$sub_title 							= 	$settings['sub_title'];
		$title 								= 	$settings['title'];
		$title_feature_image 				= 	$settings['title_feature_image'];
		$alt 								= 	( isset( $title_feature_image['alt'] ) && $title_feature_image['alt'] != '') ? $title_feature_image['alt'] : $title; 
		$description 						=  	$settings['description']; 
		$tag 								=  	$settings['html_tag'];
		$link								=  	$settings['link']['url'];
		$target 							= 	$settings['link']['is_external'] ? '_blank' : '_self';
		$nofollow      						= 	( isset( $link['nofollow'] ) && $link['nofollow'] ) ? 'rel=nofollow' : '';

		$special_text_custom 				=	$settings['special_text_custom'];

		$show_author 						=	$settings['show_author'];
		$author_prefix 						=	$settings['author_prefix'];
		$author 							=	$settings['author'];

		$show_button_booking 				=	$settings['show_button_booking'];
		$text_booking 						=	$settings['text_booking'];
		$link_booking						=  	$settings['link_booking']['url'];
		$target_booking 					= 	$settings['link_booking']['is_external'] ? '_blank' : '_self';
		$nofollow_booking      				= 	( isset( $settings['link_booking']['nofollow'] ) && $settings['link_booking']['nofollow'] ) ? 'rel=nofollow' : '';

		$show_image     					=   $settings['show_image'];
		$word_position 						= 	$settings['word_position'] 		? $settings['word_position'] 	: 0 ;
		$word_position_2 					= 	$settings['word_position_2'] 	? $settings['word_position_2']  : 20 ;
        
        if( $special_text_custom == 'yes' ){

        	// replace % to %% avoid printf error
			if(strpos($title, '%') !== false){
			    $title = str_replace('%', '%%', $title);
			}

			$explode_fullname 	= explode(' ', $title);
			
			if ( isset($explode_fullname[$word_position]) ) {

				if( $show_image == 'yes' && $title_feature_image['url'] != '' ) {
					$replace = '<div class="wrap-word"><span class="word">' . $explode_fullname[$word_position] . '</span>'."<img src='{$title_feature_image['url']}' alt='{$alt}'></div>";
				}else{
					$replace = '<span class="word">' . $explode_fullname[$word_position] . '</span>';
				}

				$title = str_replace( $explode_fullname[$word_position], $replace, $title );
			}

			if ( isset($explode_fullname[$word_position_2]) && ($word_position != $word_position_2) ) {

				$replace = '<span class="word">' . $explode_fullname[$word_position_2] . '</span>';

				$title = str_replace( $explode_fullname[$word_position_2], $replace, $title );

			}

        }
        
		?>

		<div class="ova-heading-2 <?php echo esc_attr( $template ); ?> ">

			<?php if($sub_title) : ?>
				<div class="sub-title-wrapper">
					<?php if($prefix) { ?>
						<span class="prefix"><?php echo esc_html($prefix); ?></span>
					<?php } ?>
					<h4 class="sub-title"><?php echo esc_html($sub_title); ?></h4>
				</div>
			<?php endif; ?>

			<?php if($title) : ?>
				<?php if($link) { ?>

					<<?php echo esc_attr($tag); ?> class="title">
						<a href="<?php echo esc_attr($link); ?>" target='<?php echo esc_attr($target); ?>' <?php echo esc_attr($nofollow); ?>>
							<?php printf($title); ?>
						</a>
					</<?php echo esc_attr($tag); ?>>

				<?php }else{ ?>

					<<?php echo esc_attr($tag); ?> class="title"><?php printf($title); ?></<?php echo esc_attr($tag); ?>>

				<?php } ?>

			<?php endif; ?>

			<?php if($description) { ?>
				<p class="description"><?php echo esc_html($description); ?></p>
			<?php } ?>

			<?php if( $author != '' && $show_author == 'yes' && $template == 'template1' ) { ?>
				<div class="author">
					<span class="divider"></span>
					<span class="author-prefix"><?php echo esc_html( $author_prefix ); ?></span>
					<span class="text"><?php echo esc_html($author); ?></span>
				</div>
			<?php  } ?>

			<?php if( ($text_booking != '' ) && $show_button_booking == 'yes' && $template == 'template3' 
		        && $link_booking != '' ) { ?>
				<a href="<?php echo esc_attr($link_booking); ?>" class="button-booking" target='<?php echo esc_attr($target_booking); ?>' <?php echo esc_attr($nofollow_booking); ?>>

					<?php if( $text_booking != '')  { ?>
						<span class="text-booking"><?php echo esc_html( $text_booking); ?></span>
					<?php } ?>

				</a>
			<?php  } ?>

		</div>

		<?php
	}
}
$widgets_manager->register( new Cryptlight_Elementor_Heading_2() );