<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Background;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Cryptlight_Elementor_Icon_Audio extends Widget_Base {

	
	public function get_name() {
		return 'cryptlight_elementor_icon_audio';
	}

	
	public function get_title() {
		return esc_html__( 'Icon Audio', 'cryptlight' );
	}

	
	public function get_icon() {
		return 'eicon-headphones';
	}

	
	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		wp_enqueue_script( 'cryptlight-icon-audio-wavesurfer', get_theme_file_uri('/assets/libs/wavesurfer/wavesurfer.min.js'), array('jquery'), false, true );
		return [ 'cryptlight-elementor-icon-audio' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'cryptlight' ),
			]
		);	
				
			// Add Class control
			$this->add_control(
				'url_audio',
				[
					'label' 		=> esc_html__( 'URL Audio', 'cryptlight' ),
					'type' 			=> Controls_Manager::TEXT,
					'placeholder' 	=> esc_html__( 'Enter your URL', 'cryptlight' ),
					'description' 	=> esc_html__( 'File Audio Upload URL (.mp3, .wav, .ogg)', 'cryptlight' ),
					'default' =>    'http://ovapt.com/cryptlight/wp/wp-content/uploads/2022/01/file_example_MP3.mp3',
				]
			);

			$this->add_control(
				'audio_options',
				[
					'label' 	=> esc_html__( 'Audio Options', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'url_audio!' => '',
					],
				]
			);

			$this->add_control(
				'waveColor',
				[
					'label' 	=> esc_html__( 'Wave Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> '#fff',
					'condition' => [
						'url_audio!' => '',
					],
				]
			);

			$this->add_control(
				'progressColor',
				[
					'label' 	=> esc_html__( 'Progress Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> '#ff00de',
					'condition' => [
						'url_audio!' => '',
					],
					'description' 	=> esc_html__( 'Name color, hex (#....), rgb color', 'cryptlight' ),
				]
			);

		$this->end_controls_section();

		/* Begin Section Icon Style */
		$this->start_controls_section(
            'icon_style',
            [
                'label' => esc_html__( 'Icon', 'cryptlight' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

        	$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' 		=> 'icon_background',
					'label' 	=> esc_html__( 'Background', 'cryptlight' ),
					'types' 	=> [ 'classic', 'gradient' ],
					'exclude' 	=> [ 'image' ],
					'selector' 	=> '{{WRAPPER}} .ova-icon-audio .waveform button',
				]
			);

			$this->add_responsive_control(
	            'icon_bg_size',
	            [
	                'label' 		=> esc_html__( 'Background Size', 'cryptlight' ),
	                'type' 			=> Controls_Manager::SLIDER,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-icon-audio .waveform button' => 'width: {{SIZE}}{{UNIT}}; 
	                    height: {{SIZE}}{{UNIT}};',
	                ],
	            ]
	        );

			$this->add_control(
	            'icon_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-icon-audio .waveform button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_control(
	            'icon_color',
	            [
	                'label' 	=> esc_html__( 'Icon Color', 'cryptlight' ),
	                'type' 		=> Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-icon-audio .waveform button i'=> 'color: {{VALUE}};',
	                ],
	            ]
	        );

			$this->add_responsive_control(
	            'icon_size',
	            [
	                'label' 		=> esc_html__( 'Size', 'cryptlight' ),
	                'type' 			=> Controls_Manager::SLIDER,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-icon-audio .waveform button i' => 'font-size: {{SIZE}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
        /* End Style */

		/* Begin Section Icon Audio Wrapper Style */
		$this->start_controls_section(
            'icon_audio_style',
            [
                'label' => esc_html__( 'Wrapper', 'cryptlight' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

        	$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' 		=> 'icon_audio_background',
					'label' 	=> esc_html__( 'Background', 'cryptlight' ),
					'types' 	=> [ 'classic', 'gradient' ],
					'exclude' 	=> [ 'image' ],
					'selector' 	=> '{{WRAPPER}} .ova-icon-audio',
				]
			);

			$this->add_control(
	            'icon_audio_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-icon-audio' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

			$this->add_responsive_control(
	            'icon_audio_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-icon-audio' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
        /* End Style */
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

        $url_audio     = $settings['url_audio'];
		$waveColor 	   = $settings['waveColor'];
		$progressColor = $settings['progressColor'];

		 ?>

            <div class="ova-icon-audio" 
               data-src="<?php echo esc_attr( $url_audio ); ?>" 
			   data-wave_color="<?php echo esc_attr( $waveColor ) ; ?>" 
			   data-progress_color="<?php echo esc_attr( $progressColor ) ; ?>" 
		    > 
            	<div class="waveform">
            		<button class="controls">
					    <i class="fa fa-play"></i>
					</button>
            	</div>
            </div>
		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Icon_Audio() );