<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cryptlight_Elementor_Icon_Box_Text_2 extends Widget_Base {

	public function get_name() {
		return 'cryptlight_elementor_icon_box_text_2';
	}

	public function get_title() {
		return esc_html__( 'Ova Icon Box 2', 'cryptlight' );
	}

	public function get_icon() {
		return 'eicon-gallery-grid';
	}

	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		/* Content */
		$this->start_controls_section(
				'section_content',
				[
					'label' => esc_html__( 'Content', 'cryptlight' ),
				]
			);

			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'template_1',
					'options' => [
						'template_1' => esc_html__( 'Template 1', 'cryptlight' ),
						'template_2' => esc_html__( 'Template 2', 'cryptlight' ),
						'template_3' => esc_html__( 'Template 3', 'cryptlight' ),
					],
				]
			);

			$this->add_control(
				'column',
				[
					'label' => esc_html__( 'Column', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'column_3',
					'options' => [
						'column_1' => '1',
						'column_2' => '2',
						'column_3' => '3',
						'column_4' => '4',
					],
					'condition' => [
						'template' => 'template_1',
					],
				]
			);

			$this->add_control(
				'column_2',
				[
					'label' => esc_html__( 'Column', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'column_4',
					'options' => [
						'column_1' => '1',
						'column_2' => '2',
						'column_3' => '3',
						'column_4' => '4',
					],
					'condition' => [
						'template' => 'template_2',
					],
				]
			);

			$this->add_control(
				'column_3',
				[
					'label' => esc_html__( 'Column', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'column_3',
					'options' => [
						'column_1' => '1',
						'column_2' => '2',
						'column_3' => '3',
						'column_4' => '4',
					],
					'condition' => [
						'template' => 'template_3',
					],
				]
			);

			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'far fa-image',
						'library' => 'all',
					],
				]
			);

			$repeater->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'rows' => 3,
					'default' => esc_html__( 'Blog Post & Articles', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your title here', 'cryptlight' ),
				]
			);

			$repeater->add_control(
				'show_check',
				[
					'label' => esc_html__( 'Show Check', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'cryptlight' ),
					'label_off' => esc_html__( 'Hide', 'cryptlight' ),
					'return_value' => 'yes',
					'default' => 'no',
				]
			);

			$repeater->add_control(
				'desc',
				[
					'label' => esc_html__( 'Description', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'rows' => 5,
					'default' => esc_html__( 'At vero eos et accusamus et iusto odio dignissimos ducim blanditiis praesentium voluptatum deleniti atque', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your description here', 'cryptlight' ),
				]
			);

			$repeater->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'cryptlight' ),
					'options' => [ 'url', 'is_external', 'nofollow' ],
					'default' => [
						'url' => '',
						'is_external' => false,
						'nofollow' => false,
					],
					'label_block' => true,
				]
			);

			$repeater->add_control(
				'text_link',
				[
					'label' => esc_html__( 'Text Link', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Read More', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your text here', 'cryptlight' ),
				]
			);

			$repeater->add_control(
				'item_bg_color',
				[
					'label' => esc_html__( 'Background', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} {{CURRENT_ITEM}}' => 'background-color: {{VALUE}} !important'
					],
				]
			);

			$this->add_control(
				'list',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'icon' => [
								'value' => 'fas fa-folder-minus',
							],
							'title' => esc_html__( 'Blog Post & Articles', 'cryptlight' ),
						],
						[
							'icon' => [
								'value' => 'fas fa-mail-bulk',
							],
							'title' => esc_html__( 'Social Media Ads', 'cryptlight' ),
						],
						[
							'icon' => [
								'value' => 'fas fa-gifts',
							],
							'title' => esc_html__( 'Edit and Export', 'cryptlight' ),
						],
						[
							'icon' => [
								'value' => 'fas fa-desktop',
							],
							'title' => esc_html__( 'Website Copy', 'cryptlight' ),
						],
						[
							'icon' => [
								'value' => 'fas fa-shapes',
							],
							'title' => esc_html__( 'Digital Add Copy', 'cryptlight' ),
						],
						[
							'icon' => [
								'value' => 'fas fa-shopping-cart',
							],
							'title' => esc_html__( 'Buy & Sales Copy', 'cryptlight' ),
						],
					],
					'title_field' => '{{{ title }}}',
					'condition' => [
						'template' => 'template_1',
					],
				]
			);

			/* Template 2 */
			$this->add_control(
				'list_2',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'title' => esc_html__( 'Website', 'cryptlight' ),
							'desc' => esc_html__( 'Reach out visitors proactively to boost website engage Support customers 24/7', 'cryptlight' ),
							'text_link' => esc_html__( 'More Details', 'cryptlight' ),
							'show_check' => 'yes',
						],
						[
							'title' => esc_html__( 'Messenger', 'cryptlight' ),
							'desc' => esc_html__( 'Reach out visitors proactively to boost website engage Support customers 24/7', 'cryptlight' ),
							'text_link' => esc_html__( 'More Details', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Slack', 'cryptlight' ),
							'desc' => esc_html__( 'Reach out visitors proactively to boost website engage Support customers 24/7', 'cryptlight' ),
							'text_link' => esc_html__( 'More Details', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Live Chat', 'cryptlight' ),
							'desc' => esc_html__( 'Reach out visitors proactively to boost website engage Support customers 24/7', 'cryptlight' ),
							'text_link' => esc_html__( 'More Details', 'cryptlight' ),
						],
					],
					'title_field' => '{{{ title }}}',
					'condition' => [
						'template' => 'template_2',
					],
				]
			);

			/* Template 3 */
			$this->add_control(
				'list_3',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'title' => esc_html__( 'Voice Command', 'cryptlight' ),
							'desc' => esc_html__( 'Chatsonic understands voice commands and responds just like Siri / Google Assistant.', 'cryptlight' ),
							'text_link' => esc_html__( 'Get Details Now', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Generate Content', 'cryptlight' ),
							'desc' => esc_html__( 'Chatsonic understands voice commands and responds just like Siri / Google Assistant.', 'cryptlight' ),
							'text_link' => esc_html__( 'Get Details Now', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Creating images', 'cryptlight' ),
							'desc' => esc_html__( 'Chatsonic understands voice commands and responds just like Siri / Google Assistant.', 'cryptlight' ),
							'text_link' => esc_html__( 'Get Details Now', 'cryptlight' ),
						],
					],
					'title_field' => '{{{ title }}}',
					'condition' => [
						'template' => 'template_3',
					],
				]
			);

		$this->end_controls_section();

		/* Items */
		$this->start_controls_section(
				'style_section',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'item_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'item_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'item_bg',
					'types' => [ 'classic', 'gradient', 'video' ],
					'selector' => '{{WRAPPER}} .ova-icon-box-text-2 .list .item .box',
				]
			);

			$this->start_controls_tabs(
				'item_style_tabs'
				);

				$this->start_controls_tab(
						'item_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' => 'item_border',
							'selector' => '{{WRAPPER}} .ova-icon-box-text-2 .list .item .box',
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Box_Shadow::get_type(),
						[
							'name' => 'item_box_shadow',
							'selector' => '{{WRAPPER}} .ova-icon-box-text-2 .list .item .box',
						]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'item_style_hover_tab',
						[
							'label' => esc_html__( 'Hover', 'cryptlight' ),
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' => 'item_border_hover',
							'selector' => '{{WRAPPER}} .ova-icon-box-text-2 .list .item .box:hover',
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Box_Shadow::get_type(),
						[
							'name' => 'item_box_shadow_hover',
							'selector' => '{{WRAPPER}} .ova-icon-box-text-2 .list .item .box:hover',
						]
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Icon */
		$this->start_controls_section(
				'icon_style_section',
				[
					'label' => esc_html__( 'Icon', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'icon_size',
				[
					'label' => esc_html__( 'Size', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .icon i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_width',
				[
					'label' => esc_html__( 'Width', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .icon' => 'width: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .icon svg' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_height',
				[
					'label' => esc_html__( 'Height', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .icon' => 'height: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .icon svg' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs(
					'icon_style_tabs'
				);

				$this->start_controls_tab(
						'icon_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' => 'icon_border',
							'selector' => '{{WRAPPER}} .ova-icon-box-text-2.template_1 .list .item .box .icon',
							'condition' => [
								'template' => 'template_1',
							],
						]
					);

					$this->add_control(
						'icon_outline',
						[
							'label' => esc_html__( 'Outline', 'cryptlight' ),
							'type' => \Elementor\Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 10,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box-text-2.template_1 .list .item .box .icon' => 'outline-width: {{SIZE}}{{UNIT}};',
							],
							'condition' => [
								'template' => 'template_1',
							],
						]
					);

					$this->add_control(
						'icon_outline_color',
						[
							'label' => esc_html__( 'Outline Color', 'cryptlight' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box-text-2.template_1 .list .item .box .icon' => 'outline-color: {{VALUE}}',
							],
							'condition' => [
								'template' => 'template_1',
							],
						]
					);

					$this->add_control(
						'icon_color',
						[
							'label' => esc_html__( 'Color', 'cryptlight' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .icon i' => 'color: {{VALUE}}',
								'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .icon svg' => 'fill: {{VALUE}}',
							],
						]
					);

					$this->add_control(
						'icon_bg',
						[
							'label' => esc_html__( 'Background', 'cryptlight' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box-text-2.template_1 .list .item .box .icon:after' => 'background: {{VALUE}}',
							],
							'condition' => [
								'template' => 'template_1',
							],
						]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'icon_style_hover_tab',
						[
							'label' => esc_html__( 'Hover', 'cryptlight' ),
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' => 'icon_border_hover',
							'selector' => '{{WRAPPER}} .ova-icon-box-text-2.template_1 .list .item .box:hover .icon',
							'condition' => [
								'template' => 'template_1',
							],
						]
					);

					$this->add_control(
						'icon_outline_hover',
						[
							'label' => esc_html__( 'Outline', 'cryptlight' ),
							'type' => \Elementor\Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
							'range' => [
								'px' => [
									'min' => 0,
									'max' => 10,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box-text-2.template_1 .list .item .box:hover .icon' => 'outline-width: {{SIZE}}{{UNIT}};',
							],
							'condition' => [
								'template' => 'template_1',
							],
						]
					);

					$this->add_control(
						'icon_outline_color_hover',
						[
							'label' => esc_html__( 'Outline Color', 'cryptlight' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box-text-2.template_1 .list .item .box:hover .icon' => 'outline-color: {{VALUE}}',
							],
							'condition' => [
								'template' => 'template_1',
							],
						]
					);

					$this->add_control(
						'icon_color_hover',
						[
							'label' => esc_html__( 'Color', 'cryptlight' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box:hover .icon i' => 'color: {{VALUE}}',
								'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box:hover .icon svg' => 'fill: {{VALUE}}',
							],
						]
					);

					$this->add_control(
						'icon_bg_hover',
						[
							'label' => esc_html__( 'Background', 'cryptlight' ),
							'type' => \Elementor\Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-icon-box-text-2.template_1 .list .item .box:hover .icon:after' => 'background: {{VALUE}}',
							],
							'condition' => [
								'template' => 'template_1',
							],
						]
					);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Title */
		$this->start_controls_section(
				'title_style_section',
				[
					'label' => esc_html__( 'Title', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'title_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .content .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'title_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .content .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'title_typography',
					'selector' => '{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .content .title a',
				]
			);

			$this->start_controls_tabs(
					'title_style_tabs'
				);

				$this->start_controls_tab(
						'title_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'title_color',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .content .title a' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'title_style_hover_tab',
						[
							'label' => esc_html__( 'Hover', 'cryptlight' ),
						]
					);

				$this->add_control(
					'title_color_hover',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .content .title a:hover' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Description */
		$this->start_controls_section(
				'desc_style_section',
				[
					'label' => esc_html__( 'Description', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'desc_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .content .desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'desc_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .content .desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'desc_typography',
					'selector' => '{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .content .desc',
				]
			);

			$this->add_control(
				'desc_color',
				[
					'label' => esc_html__( 'Color', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .content .desc' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

		/* Text Link */
		$this->start_controls_section(
				'text_link_style_section',
				[
					'label' => esc_html__( 'Text Link', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'text_link_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .link' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'text_link_typography',
					'selector' => '{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .link',
				]
			);

			$this->start_controls_tabs(
					'text_link_style_tabs'
				);

				$this->start_controls_tab(
						'text_link_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'text_link_color',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .link' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'text_link_style_hover_tab',
						[
							'label' => esc_html__( 'Hover', 'cryptlight' ),
						]
					);

				$this->add_control(
					'text_link_color_hover',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-icon-box-text-2 .list .item .box .link:hover' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();
	}

	// Render Template Here
	protected function render() {
		$settings 	= $this->get_settings();
		$template 	= $settings['template'];
		$column 	= $settings['column'];
		if ( $template == 'template_2' ) {
			$column = $settings['column_2'];
		}
		if ( $template == 'template_3' ) {
			$column = $settings['column_3'];
		}
		$list = $settings['list'];
		if ( $template == 'template_2' ) {
			$list = $settings['list_2'];
		}
		if ( $template == 'template_3' ) {
			$list = $settings['list_3'];
		}
		?>
		<div class="ova-icon-box-text-2 <?php echo esc_attr( $template . ' ' . $column ); ?>">
			<?php if ( $list ): ?>
				<ul class="list">
					<?php foreach ($list as $key => $item): ?>
						<?php
							$icon 		= $item['icon'];
							$title 		= $item['title'];
							$check 		= $item['show_check'];
							$desc 		= $item['desc'];
							$text_link 	= $item['text_link'];
							$link 		= $item['link']['url'];
							$nofollow 	= $item['link']['nofollow'] 	? 'rel="nofollow"' 	: '';
							$target 	= $item['link']['is_external'] 	? 'target="_blank"' : '';
						?>
						<li class="item">
							<div class="box elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?>">
								<?php if ( $template != 'template_3' ): ?>
									<span class="icon">
										<?php \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] ); ?>
									</span>
								<?php endif; ?>
								<div class="content">
									<?php if ( $title ): ?>
										<h3 class="title">
											<a href="<?php echo esc_url( $link ); ?>"
												title="<?php echo esc_attr( $title ); ?>"
												<?php printf( '%1$s %2$s', $nofollow, $target ); ?>>
												<?php echo esc_html( $title ); ?>
											</a>
											<?php if ( $check == 'yes' ): ?>
												<i class="fas fa-check-circle" aria-hidden="true"></i>
											<?php endif; ?>
										</h3>
									<?php endif; ?>
									<?php if ( $desc ): ?>
										<p class="desc"><?php echo esc_html( $desc ); ?></p>
									<?php endif; ?>
								</div>
								<?php if ( $text_link ): ?>
									<a href="<?php echo esc_url( $link ); ?>"
										<?php printf( '%1$s %2$s', $nofollow, $target ); ?>
										title="<?php echo esc_attr( $text_link ); ?>" class="link">
										<?php echo esc_html( $text_link ); ?>
										<i class="ovaicon-next-4" aria-hidden="true"></i>
									</a>
								<?php endif; ?>
								<?php if ( $template == 'template_3' ): ?>
									<span class="icon">
										<?php \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] ); ?>
									</span>
								<?php endif; ?>
							</div>
						</li>

					<?php endforeach; ?>
				</ul>
			<?php endif; ?>
		</div>
		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Icon_Box_Text_2() );