<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cryptlight_Elementor_Icon_Box_Text extends Widget_Base {

	public function get_name() {
		return 'cryptlight_elementor_icon_box_text';
	}

	public function get_title() {
		return esc_html__( 'Ova Icon Box', 'cryptlight' );
	}

	public function get_icon() {
		return 'eicon-post-list';
	}

	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		/* Content */
		$this->start_controls_section(
				'section_content',
				[
					'label' => esc_html__( 'Content', 'cryptlight' ),
				]
			);

			$this->add_control(
				'template',
				[
					'label' => esc_html__( 'Template', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'template_1',
					'options' => [
						'template_1' => esc_html__( 'Template 1', 'cryptlight' ),
						'template_2' => esc_html__( 'Template 2', 'cryptlight' ),
						'template_3' => esc_html__( 'Template 3', 'cryptlight' ),
					],
				]
			);

			$this->add_control(
				'column',
				[
					'label' => esc_html__( 'Column', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'column_1',
					'options' => [
						'column_1' => '1',
						'column_2' => '2',
						'column_3' => '3',
						'column_4' => '4',
					],
					'condition' => [
						'template' => 'template_1',
					],
				]
			);

			$this->add_control(
				'column_2',
				[
					'label' => esc_html__( 'Column', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'column_3',
					'options' => [
						'column_1' => '1',
						'column_2' => '2',
						'column_3' => '3',
						'column_4' => '4',
					],
					'condition' => [
						'template' => 'template_2',
					],
				]
			);

			$this->add_control(
				'column_3',
				[
					'label' => esc_html__( 'Column', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'column_4',
					'options' => [
						'column_1' => '1',
						'column_2' => '2',
						'column_3' => '3',
						'column_4' => '4',
					],
					'condition' => [
						'template' => 'template_3',
					],
				]
			);

			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'cryptlight' ),
					'options' => [ 'url', 'is_external', 'nofollow' ],
					'default' => [
						'url' => '',
						'is_external' => false,
						'nofollow' => false,
					],
					'label_block' => true,
				]
			);

			$repeater->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::ICONS,
					'default' => [
						'value' => 'far fa-image',
						'library' => 'all',
					],
				]
			);

			$repeater->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'rows' => 3,
					'default' => esc_html__( 'Write Blog High 10X Faster', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your title here', 'cryptlight' ),
				]
			);

			$repeater->add_control(
				'desc',
				[
					'label' => esc_html__( 'Description', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'rows' => 5,
					'default' => esc_html__( 'At vero eos et accusamus et iusteodis dignissimos ducim blanditiis', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your description here', 'cryptlight' ),
				]
			);

			$repeater->add_control(
				'item_bg',
				[
					'label' => esc_html__( 'Background', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} {{CURRENT_ITEM}}' => 'background: {{VALUE}}',
					],
				]
			);

			$repeater->add_control(
				'item_border_color',
				[
					'label' => esc_html__( 'Border Color', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} {{CURRENT_ITEM}}' => 'border-color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'list',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'title' => esc_html__( 'Write Blog High 10X Faster', 'cryptlight' ),
							'desc' => esc_html__( 'At vero eos et accusamus et iusteodis dignissimos ducim blanditiis', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Write Higher Converting Post', 'cryptlight' ),
							'desc' => esc_html__( 'At vero eos et accusamus et iusteodis dignissimos ducim blanditiis', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Write More Engaging Emails', 'cryptlight' ),
							'desc' => esc_html__( 'Dignissimos ducim blanditiis praesentium voluptatum deleniti atque', 'cryptlight' ),
						],
					],
					'title_field' => '{{{ title }}}',
					'condition' => [
						'template' => 'template_1',
					],
				]
			);

			/* Template 2 */
			$this->add_control(
				'list_2',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'title' => esc_html__( 'Natural Language', 'cryptlight' ),
							'desc' => esc_html__( 'Be advised that image .', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Reliable Express', 'cryptlight' ),
							'desc' => esc_html__( 'Be advised that image .', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Leatest Technology', 'cryptlight' ),
							'desc' => esc_html__( 'Be advised that image .', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Charts & Graphs', 'cryptlight' ),
							'desc' => esc_html__( 'Be advised that image .', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Endless possibilities', 'cryptlight' ),
							'desc' => esc_html__( 'Be advised that image .', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Excellent Support', 'cryptlight' ),
							'desc' => esc_html__( 'Be advised that image .', 'cryptlight' ),
						],
					],
					'title_field' => '{{{ title }}}',
					'condition' => [
						'template' => 'template_2',
					],
				]
			);

			/* Template 3 */
			$this->add_control(
				'list_3',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'title' => esc_html__( 'Live chat', 'cryptlight' ),
							'desc' => esc_html__( 'Connect with customer', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Help Desk', 'cryptlight' ),
							'desc' => esc_html__( 'Support customers with tickets', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'Chat GPT API', 'cryptlight' ),
							'desc' => esc_html__( 'Connect with customers', 'cryptlight' ),
						],
						[
							'title' => esc_html__( 'AI Image Genarator', 'cryptlight' ),
							'desc' => esc_html__( 'Connect with customers', 'cryptlight' ),
						],
					],
					'title_field' => '{{{ title }}}',
					'condition' => [
						'template' => 'template_3',
					],
				]
			);

		$this->end_controls_section();

		/* Items */
		$this->start_controls_section(
				'style_section',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'item_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'item_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs(
					'item_style_tabs'
				);

				$this->start_controls_tab(
						'item_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_group_control(
					\Elementor\Group_Control_Border::get_type(),
					[
						'name' => 'item_border',
						'selector' => '{{WRAPPER}} .ova-icon-box-text .list .item .box',
					]
				);

				$this->add_control(
					'item_bg_all',
					[
						'label' => esc_html__( 'Background', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-icon-box-text .list .item .box' => 'background: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'item_style_hover_tab',
						[
							'label' => esc_html__( 'Hover', 'cryptlight' ),
						]
					);

				$this->add_group_control(
					\Elementor\Group_Control_Border::get_type(),
					[
						'name' => 'item_border_hover',
						'selector' => '{{WRAPPER}} .ova-icon-box-text .list .item .box:hover',
					]
				);

				$this->add_control(
					'item_bg_all_hover',
					[
						'label' => esc_html__( 'Background', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-icon-box-text .list .item .box:hover' => 'background: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Icon */
		$this->start_controls_section(
				'icon_style_section',
				[
					'label' => esc_html__( 'Icon', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'icon_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'icon_border',
					'selector' => '{{WRAPPER}} .ova-icon-box-text .list .item .box .icon',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'icon_box_shadow',
					'selector' => '{{WRAPPER}} .ova-icon-box-text .list .item .box .icon',
				]
			);

			$this->add_responsive_control(
				'icon_size',
				[
					'label' => esc_html__( 'Size', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .icon' => 'flex: 0 0 {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .icon svg' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .icon i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'icon_color',
				[
					'label' => esc_html__( 'Color', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .icon svg' => 'fill: {{VALUE}}',
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .icon i' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'icon_bg',
				[
					'label' => esc_html__( 'Background', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .icon' => 'background: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

		/* Title */
		$this->start_controls_section(
				'title_style_section',
				[
					'label' => esc_html__( 'Title', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'title_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .content .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'title_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .content .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'title_typography',
					'selector' => '{{WRAPPER}} .ova-icon-box-text .list .item .box .content .title,{{WRAPPER}} .ova-icon-box-text .list .item .box .content .title a,',
				]
			);

			$this->start_controls_tabs(
				'title_style_tabs'
				);

				$this->start_controls_tab(
						'title_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'title_color',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-icon-box-text .list .item .box .content .title' => 'color: {{VALUE}}',
							'{{WRAPPER}} .ova-icon-box-text .list .item .box .content .title a' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'title_style_hover_tab',
						[
							'label' => esc_html__( 'Hover', 'cryptlight' ),
						]
					);

				$this->add_control(
					'title_color_hover',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-icon-box-text .list .item .box .content .title:hover' => 'color: {{VALUE}}',
							'{{WRAPPER}} .ova-icon-box-text .list .item .box .content .title a:hover' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Description */
		$this->start_controls_section(
				'desc_style_section',
				[
					'label' => esc_html__( 'Description', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'desc_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .content .desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'desc_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .content .desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'desc_typography',
					'selector' => '{{WRAPPER}} .ova-icon-box-text .list .item .box .content .desc',
				]
			);

			$this->add_control(
				'desc_color',
				[
					'label' => esc_html__( 'Color', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-icon-box-text .list .item .box .content .desc' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();
	}

	// Render Template Here
	protected function render() {
		$settings 	= $this->get_settings();
		$template 	= $settings['template'];
		$column 	= $settings['column'];
		if ( $template == 'template_2' ) {
			$column = $settings['column_2'];
		}
		if ( $template == 'template_3' ) {
			$column = $settings['column_3'];
		}
		$list 		= $settings['list'];
		if ( $template == 'template_2' ) {
			$list = $settings['list_2'];
		}
		if ( $template == 'template_3' ) {
			$list = $settings['list_3'];
		}
		?>
		<div class="ova-icon-box-text <?php echo esc_attr( $template . ' ' . $column ); ?>">
			<?php if ( $list ): ?>
				<ul class="list">
					<?php foreach ($list as $item): ?>
						<?php
							$icon 		= $item['icon'];
							$link 		= $item['link'];
							$title 		= $item['title'];
							$desc 		= $item['desc'];
							$nofollow 	= $link['nofollow'] 	? 'rel="nofollow"' 	: '';
							$target 	= $link['is_external'] 	? 'target="_blank"' : '';
						?>
						<li class="item">
							<div class="box elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?>">
								<?php if ( $icon ): ?>
									<div class="icon">
										<?php \Elementor\Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] ); ?>
									</div>
								<?php endif; ?>
								<div class="content">
									<?php if ( $title ): ?>
										<h3 class="title">
											<?php if ( $link['url'] ): ?>
												<a href="<?php echo esc_url( $link['url'] ); ?>"
													title="<?php echo esc_attr( $title ); ?>"
													<?php printf( '%1$s %2$s', $nofollow, $target ); ?>>
													<?php echo esc_html( $title ); ?>
												</a>
											<?php else: ?>
												<?php echo esc_html( $title ); ?>
											<?php endif ?>
										</h3>
									<?php endif; ?>
									<?php if ( $desc ): ?>
										<p class="desc"><?php echo esc_html( $desc ); ?></p>
									<?php endif; ?>
								</div>
							</div>
						</li>

					<?php endforeach; ?>
				</ul>
			<?php endif; ?>
		</div>
		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Icon_Box_Text() );