<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Cryptlight_Elementor_Igenerator_Form extends Widget_Base {

	
	public function get_name() {
		return 'cryptlight_elementor_igenerator_form';
	}

	
	public function get_title() {
		return esc_html__( 'Igenerator Form', 'cryptlight' );
	}

	
	public function get_icon() {
		return 'eicon-form-vertical';
	}

	
	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ 'cryptlight-elementor-igenerator-form' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		/* Begin Content */
		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'cryptlight' ),
			]
		);	
			
			// Add Class control
			$this->add_control(
				'placeholder',
				[
					'label' 	=> esc_html__( 'Placeholder', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'Describe what you want or hit a tag below', 'cryptlight' ),
				]
			);

			$this->add_control(
				'tags_heading',
				[
					'label' 	=> esc_html__( 'Tags Heading', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'Popular Tags:', 'cryptlight' ),
				]
			);

			$this->add_control(
				'text_button',
				[
					'label' 	=> esc_html__( 'Text button', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'Generate', 'cryptlight' ),
				]
			);

			$this->add_control(
	            'link_button',
	            [
	                'label' 		=> esc_html__( 'Link Button', 'cryptlight' ),
	                'type' 			=> Controls_Manager::URL,
	                'placeholder' 	=> esc_html__( 'https://your-link.com', 'cryptlight' ),
	                'default' => [
	                    'url' => '#',
	                    'is_external' => false,
						'nofollow' => true,
	                ],
	                'dynamic' => [
	                    'active' => true,
	                ],
	            ]
	        );

	        $repeater = new \Elementor\Repeater();

				$repeater->add_control(
					'tag',
					[
						'label' 	=> esc_html__( 'Tag', 'cryptlight' ),
						'type' 		=> Controls_Manager::TEXT,
						'default' 	=> esc_html__( 'Creative', 'cryptlight' ),
					]
				);

				$repeater->add_control(
					'tag_link',
		            [
		                'label' 		=> esc_html__( 'Link', 'cryptlight' ),
		                'type' 			=> Controls_Manager::URL,
		                'placeholder' 	=> esc_html__( 'https://your-link.com', 'cryptlight' ),
		                'dynamic' => [
		                    'active' => true,
		                ],
		            ]
				);

			$this->add_control(
				'tag_items',
				[
					'label' 	=> esc_html__( 'Items', 'cryptlight' ),
					'type' 		=> Controls_Manager::REPEATER,
					'fields' 	=> $repeater->get_controls(),
					'default' 	=> [
						[
							'tag' => esc_html__( 'creative', 'cryptlight' ),
						],
						[
							'tag' => esc_html__( 'flowers', 'cryptlight' ),
						],
						[
							'tag' => esc_html__( 'lanscape', 'cryptlight' ),
						],
						[
							'tag' => esc_html__( 'technology', 'cryptlight' ),
						],
						[
							'tag' => esc_html__( 'space', 'cryptlight' ),
						]
					],
					'title_field' => '{{{ tag }}}',
				]
			);

		$this->end_controls_section();
		/* End Content */
	}

	// Render Template Here
	protected function render() {

		$settings 	= $this->get_settings();

		$placeholder  = $settings['placeholder'];
		$text_button  = $settings['text_button'];
		$tags_heading = $settings['tags_heading'];
		$link_button  = $settings['link_button']['url'];

		$tg_blank 	= '';
		if ( $settings['link_button']['is_external'] == 'on' ) {
			$tg_blank = 'target="_blank"';
		}

		$tag_items  = $settings['tag_items'];

		?>

		<div class="ova-igenerator-form">
			<div class="igenerator_form_field_inner">
				<input type="text" class="igenerator_form_field_prompt_text" placeholder="<?php echo esc_attr($placeholder);?>">
				<a href="<?php echo esc_url($link_button);?>" class="igenerator_form_field_prompt_button" <?php printf($tg_blank);?>>
					<?php echo esc_html($text_button);?>
				</a>
			</div>
			<div class="igenerator_form_field_tags">
				<span class="label">
					<?php echo esc_html($tags_heading);?>
				</span>
				<span class="igenerator_form_field_tags_list">
					<?php foreach ( $tag_items as $tag_item ): 
						$tag 			= $tag_item['tag'];
						$tag_link 		= $tag_item['tag_link']['url'];
						$tag_tg_blank 	= '';
						if ( $tag_item['tag_link']['is_external'] == 'on' ) {
							$tag_tg_blank = 'target="_blank"';
						}
					?>
						<?php if( !empty($tag_link) ) { ?>
							<a href="<?php echo esc_url($tag_link);?>" class="tags_item" <?php printf($tag_tg_blank);?>>
								<?php echo esc_html($tag);?>	
							</a>
						<?php } else { ?>
							<span class="tags_item" 
								data-tag_prompt="<?php echo esc_attr__('Generate','cryptlight') . ' ' . $tag . ' ' . esc_attr__('images','cryptlight'); ?>">
								<?php echo esc_html($tag);?>	
							</span>
						<?php } ?>
					<?php endforeach;?>
				</span>
			</div>
		</div>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Igenerator_Form() );