<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cryptlight_Elementor_Itext_Box extends Widget_Base {

	public function get_name() {
		return 'cryptlight_elementor_itext_box';
	}

	public function get_title() {
		return esc_html__( 'Itext Box', 'cryptlight' );
	}

	public function get_icon() {
		return 'eicon-flip-box';
	}

	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_text_box',
			[
				'label' => esc_html__( 'Itext Box', 'cryptlight' ),
			]
		);	
			
			// Add Class control
		    $this->add_control(
				'image',
				[
					'label' 	=> esc_html__( 'Image', 'cryptlight' ),
					'type' 		=> Controls_Manager::MEDIA,
					'dynamic' 	=> [
						'active' 	=> true,
					],
					'default' 	=> [
						'url' 	=> Utils::get_placeholder_image_src(),
					],
				]
			);

			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'i,m Chatbot Your Assitant_', 'cryptlight' ),
				]
			);

			$this->add_control(
				'show_shape',
				[
					'label' 		=> esc_html__( 'Show Shape', 'cryptlight' ),
					'type' 			=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 		=> esc_html__( 'Show', 'cryptlight' ),
					'label_off' 	=> esc_html__( 'Hide', 'cryptlight' ),
					'return_value' 	=> 'yes',
					'default' 		=> 'no',
				],
			);

		$this->end_controls_section();

		/* Begin Title Style */
		$this->start_controls_section(
            'title_style',
            [
                'label' => esc_html__( 'Title', 'cryptlight' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

	        $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-itext-box .wrap-box .title',
				]
			);

			$this->add_control(
	            'title_color',
	            [
	                'label' 	=> esc_html__( 'Color', 'cryptlight' ),
	                'type' 		=> Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-itext-box .wrap-box .title' => 'color: {{VALUE}}',
	                ],
	            ]
	        );

			$this->add_responsive_control(
	            'title_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-itext-box .wrap-box .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
		/* End Title Style */

	}

	// Render Template Here
	protected function render() {

		$settings 	= $this->get_settings();

		$title 		= $settings['title'];

		// Get url image
		$url 	= $settings['image']['url'];
		$alt 	= isset( $settings['image']['alt'] ) ? $settings['image']['alt'] : '';

		if ( empty( $alt ) ) {
			$alt = $title ? $title : esc_html__( 'AI Assitant', 'cryptlight' );
		}

		$show_shape = $settings['show_shape'];

		?>

		<div class="ova-itext-box">
			<?php if( !empty($url) ) : ?>
				<div class="image">
					<img src="<?php echo esc_url($url);?>" alt="<?php echo esc_url($alt);?>">
				</div>
			<?php endif; ?>
			<div class="wrap-box">
				<h2 class="title"><?php echo esc_html( $title ); ?>	</h2>
				<?php if( $show_shape == 'yes' ) :?>
					<div class="shape"></div>
				<?php endif; ?>
			</div>
		</div>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Itext_Box() );