<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cryptlight_Elementor_Price extends Widget_Base {

	public function get_name() {
		return 'cryptlight_elementor_price';
	}

	public function get_title() {
		return esc_html__( 'Ova Price', 'cryptlight' );
	}

	public function get_icon() {
		return 'eicon-price-table';
	}

	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		/* Content */
		$this->start_controls_section(
				'section_content',
				[
					'label' => esc_html__( 'Content', 'cryptlight' ),
				]
			);

			$this->add_control(
				'title',
				[
					'label' => esc_html__( 'Title', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Basic Plan', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your title here', 'cryptlight' ),
					'label_block' => true,
				]
			);

			$this->add_control(
				'price',
				[
					'label' => esc_html__( 'Price', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( '$19.99/', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your price here', 'cryptlight' ),
					'label_block' => true,
				]
			);

			$this->add_control(
				'price_after',
				[
					'label' => esc_html__( 'After Price', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'per month', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your price here', 'cryptlight' ),
					'label_block' => true,
				]
			);

			$this->add_control(
				'desc',
				[
					'label' => esc_html__( 'Description', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'rows' => 3,
					'default' => esc_html__( 'Accusamus etiusto dignissimos ducim blanditiis praesen voluptatum', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your description here', 'cryptlight' ),
				]
			);

			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'cryptlight' ),
					'options' => [ 'url', 'is_external', 'nofollow' ],
					'default' => [
						'url' => '',
						'is_external' => true,
						'nofollow' => false,
					],
					'label_block' => true,
				]
			);

			$this->add_control(
				'text_link',
				[
					'label' => esc_html__( 'Text Link', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => esc_html__( 'Get Started Now', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your text here', 'cryptlight' ),
					'label_block' => true,
				]
			);

			$this->add_control(
				'text_align',
				[
					'label' => esc_html__( 'Alignment', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => esc_html__( 'Left', 'cryptlight' ),
							'icon' => 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'cryptlight' ),
							'icon' => 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'cryptlight' ),
							'icon' => 'eicon-text-align-right',
						],
					],
					'default' => 'center',
					'toggle' => true,
					'selectors' => [
						'{{WRAPPER}} .ova-price' => 'text-align: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'active',
				[
					'label' => esc_html__( 'Active', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'return_value' => 'yes',
					'default' => 'no',
				]
			);

			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'icon',
				[
					'label' => esc_html__( 'Icon Class', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXT,
					'default' => 'fas fa-check',
					'placeholder' => esc_html__( 'Type your icon here', 'cryptlight' ),
					'label_block' => true,
				]
			);

			$repeater->add_control(
				'content',
				[
					'label' => esc_html__( 'Content', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'rows' => 3,
					'default' => esc_html__( '15,853 Monthly Word Limit', 'cryptlight' ),
					'placeholder' => esc_html__( 'Type your content here', 'cryptlight' ),
				]
			);

			$repeater->add_control(
				'highlight',
				[
					'label' => esc_html__( 'Highlight Word', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::NUMBER,
					'min' => 1,
					'max' => 100,
					'step' => 1,
				]
			);

			$this->add_control(
				'list',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'content' => esc_html__( '15,853 Monthly Word Limit', 'cryptlight' ),
							'highlight' => 1,
						],
						[
							'content' => esc_html__( '12+ Templates', 'cryptlight' ),
							'highlight' => 1,
						],
						[
							'content' => esc_html__( '35+ Languages', 'cryptlight' ),
							'highlight' => 1,
						],
						[
							'content' => esc_html__( 'Advance Editor Tool', 'cryptlight' ),
						],
						[
							'content' => esc_html__( 'Custom Managements', 'cryptlight' ),
						],
					],
					'title_field' => '{{{ content }}}',
				]
			);

		$this->end_controls_section();

		/* General */
		$this->start_controls_section(
				'general_style_section',
				[
					'label' => esc_html__( 'General', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'general_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'general_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs(
					'general_style_tabs'
				);

				$this->start_controls_tab(
						'general_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'general_bg',
					[
						'label' => esc_html__( 'Background', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price' => 'background: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'general_style_active_tab',
						[
							'label' => esc_html__( 'Active', 'cryptlight' ),
						]
					);

				$this->add_control(
					'general_bg_active',
					[
						'label' => esc_html__( 'Background', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price.is-active' => 'background: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Title */
		$this->start_controls_section(
				'title_style_section',
				[
					'label' => esc_html__( 'Title', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'title_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'title_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'title_typography',
					'selector' => '{{WRAPPER}} .ova-price .title',
				]
			);

			$this->start_controls_tabs(
					'title_style_tabs'
				);

				$this->start_controls_tab(
						'title_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'title_color',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price .title' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'title_style_active_tab',
						[
							'label' => esc_html__( 'Active', 'cryptlight' ),
						]
					);

				$this->add_control(
					'title_color_active',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price.is-active .title' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Price */
		$this->start_controls_section(
				'price_style_section',
				[
					'label' => esc_html__( 'Price', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'price_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .price .number' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'price_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .price .number' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'price_typography',
					'selector' => '{{WRAPPER}} .ova-price .price .number',
				]
			);

			$this->start_controls_tabs(
					'price_style_tabs'
				);

				$this->start_controls_tab(
						'price_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'price_color',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price .price .number' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'price_style_active_tab',
						[
							'label' => esc_html__( 'Active', 'cryptlight' ),
						]
					);

				$this->add_control(
					'price_color_active',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price.is-active .price .number' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* After Price */
		$this->start_controls_section(
				'after_price_style_section',
				[
					'label' => esc_html__( 'After Price', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'after_price_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .price .after_number' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'after_price_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .price .after_number' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'after_price_typography',
					'selector' => '{{WRAPPER}} .ova-price .price .after_number',
				]
			);

			$this->start_controls_tabs(
					'after_price_style_tabs'
				);

				$this->start_controls_tab(
						'after_price_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'after_price_color',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price .price .after_number' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'after_price_style_active_tab',
						[
							'label' => esc_html__( 'Active', 'cryptlight' ),
						]
					);

				$this->add_control(
					'after_price_color_active',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price.is-active .price .after_number' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Description */
		$this->start_controls_section(
				'desc_style_section',
				[
					'label' => esc_html__( 'Description', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'desc_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'desc_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'desc_typography',
					'selector' => '{{WRAPPER}} .ova-price .desc',
				]
			);

			$this->start_controls_tabs(
					'desc_style_tabs'
				);

				$this->start_controls_tab(
						'desc_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'desc_color',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price .desc' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'desc_style_active_tab',
						[
							'label' => esc_html__( 'Active', 'cryptlight' ),
						]
					);

				$this->add_control(
					'desc_color_active',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price.is-active .desc' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Text Link */
		$this->start_controls_section(
				'text_link_style_section',
				[
					'label' => esc_html__( 'Text Link', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'text_link_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .link' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'text_link_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .link' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'text_link_typography',
					'selector' => '{{WRAPPER}} .ova-price .link',
				]
			);

			$this->start_controls_tabs(
					'text_link_style_tabs'
				);

				$this->start_controls_tab(
						'text_link_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_group_control(
					\Elementor\Group_Control_Border::get_type(),
					[
						'name' => 'text_link_border',
						'selector' => '{{WRAPPER}} .ova-price .link',
					]
				);

				$this->add_control(
					'text_link_bg',
					[
						'label' => esc_html__( 'Background', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price .link' => 'background: {{VALUE}}',
						],
					]
				);

				$this->add_control(
					'text_link_color',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price .link' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'text_link_style_active_tab',
						[
							'label' => esc_html__( 'Active', 'cryptlight' ),
						]
					);

				$this->add_group_control(
					\Elementor\Group_Control_Border::get_type(),
					[
						'name' => 'text_link_border_active',
						'selector' => '{{WRAPPER}} .ova-price.is-active .link',
					]
				);

				$this->add_control(
					'text_link_bg_active',
					[
						'label' => esc_html__( 'Background', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price.is-active .link' => 'background: {{VALUE}}',
						],
					]
				);

				$this->add_control(
					'text_link_color_active',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price.is-active .link' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Items */
		$this->start_controls_section(
				'items_style_section',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'items_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'items_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		/* Icon */
		$this->start_controls_section(
				'icon_style_section',
				[
					'label' => esc_html__( 'Icon', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'icon_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .list .item .content i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_size',
				[
					'label' => esc_html__( 'Size', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 40,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-price .list .item .content i' => 'font-size: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs(
					'icon_style_tabs'
				);

				$this->start_controls_tab(
						'icon_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'icon_color',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price .list .item .content i' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'icon_style_active_tab',
						[
							'label' => esc_html__( 'Active', 'cryptlight' ),
						]
					);

				$this->add_control(
					'icon_color_active',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price.is-active .list .item .content i' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();

		/* Content */
		$this->start_controls_section(
				'content_style_section',
				[
					'label' => esc_html__( 'Content', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'content_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .list .item .content .text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'content_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-price .list .item .content .text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'content_typography',
					'selector' => '{{WRAPPER}} .ova-price .list .item .content .text',
				]
			);

			$this->start_controls_tabs(
					'content_style_tabs'
				);

				$this->start_controls_tab(
						'content_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'content_color',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price .list .item .content .text' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'content_style_active_tab',
						[
							'label' => esc_html__( 'Active', 'cryptlight' ),
						]
					);

				$this->add_control(
					'content_color_active',
					[
						'label' => esc_html__( 'Color', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-price.is-active .list .item .content .text' => 'color: {{VALUE}}',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();
	}

	// Render Template Here
	protected function render() {
		$settings 		= $this->get_settings();
		$title 			= $settings['title'];
		$title 			= $settings['title'];
		$price 			= $settings['price'];
		$price_after	= $settings['price_after'];
		$desc 			= $settings['desc'];
		$link 			= $settings['link']['url'];
		$text_link 		= $settings['text_link'];
		$nofollow 		= $settings['link']['nofollow'] 	? 'rel="nofollow"' 	: '';
		$target 		= $settings['link']['is_external'] 	? 'target="_blank"' : '';
		$active 		= $settings['active'] == 'yes' ? 'is-active' : '';
		$list 			= $settings['list'];
		?>
		<div class="ova-price <?php echo esc_attr( $active ); ?>">
			<div class="info">
				<h3 class="title"><?php echo esc_html( $title ); ?></h3>
				<p class="price">
					<span class="number"><?php echo esc_html( $price ); ?></span>
					<span class="after_number"><?php echo esc_html( $price_after ); ?></span>
				</p>
				<p class="desc"><?php echo esc_html( $desc ); ?></p>
				<a href="<?php echo esc_url( $link ); ?>"
					title="<?php echo esc_attr( $text_link ); ?>"
					<?php printf( '%1$s %2$s', $nofollow, $target ); ?>
					class="link">
					<?php echo esc_html( $text_link ); ?>
					<i class="fas fa-arrow-right" aria-hidden="true"></i>
				</a>
			</div>
			<?php if ( $list ): ?>
				<ul class="list">
					<?php foreach ($list as $key => $item): ?>
						<?php
							$icon 			= $item['icon'];
							$content 		= $item['content'];
							$highlight 		= $item['highlight'];
							$new_content 	= '';
							if ( $highlight && $content ) {
								$content_to_arr = explode(" ", $content);
								$index = $highlight - 1;
								if ( array_key_exists( $index, $content_to_arr ) ) {
									// replace word
									$content_to_arr[$index] = '<span class="highlight">' . $content_to_arr[$index] . '</span>';
									$new_content = implode( " ", $content_to_arr );
								}
							}
						?>
						<li class="item">
							<p class="content">
								<?php if ( $icon ): ?>
									<i class="<?php echo esc_attr( $icon ); ?>" aria-hidden="true"></i>
								<?php endif; ?>
								<span class="text">
									<?php if ( $new_content ):
										printf('%s',$new_content);
									else:
										echo esc_html( $content );
									endif; ?>
								</span>
							</p>
						</li>
					<?php endforeach; ?>
				</ul>
			<?php endif; ?>
		</div>
		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Price() );