<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Cryptlight_Elementor_Road_Map_2 extends Widget_Base {

	
	public function get_name() {
		return 'cryptlight_elementor_road_map_2';
	}

	
	public function get_title() {
		return esc_html__( 'Road Map 2', 'cryptlight' );
	}

	
	public function get_icon() {
		return 'eicon-time-line';
	}

	
	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		wp_enqueue_script( 'cryptlight-road-map-2-appear', get_theme_file_uri('/assets/libs/appear/appear.js'), array('jquery'), false, true);
		return [ 'cryptlight-elementor-road-map-2' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

			/* Begin section road map */
		$this->start_controls_section(
			'section_road_map',
			[
				'label' => esc_html__( 'Road Map', 'cryptlight' ),
			]
		);	
			
			$this->add_control(
	            'type',
	            [
	                'label' 	=> esc_html__( 'Type', 'cryptlight' ),
	                'type' 		=> Controls_Manager::SELECT,
	                'options' 	=> [
	                    'v1' => esc_html__( 'Type 1', 'cryptlight' ),
	                    'v2' => esc_html__( 'Type 2', 'cryptlight' ),
	                    'v3' => esc_html__( 'Type 3', 'cryptlight' ),
	                ],
	                'default' 	=> 'v1',
	            ]
	        );

	        $this->add_control(
	            'date_format',
	            [
	                'label' 	=> esc_html__( 'Date Format', 'cryptlight' ),
	                'type' 		=> Controls_Manager::SELECT,
	                'options' 	=> [
	                    'quarter' => esc_html__( 'Quarter', 'cryptlight' ),
	                    'month' => esc_html__( 'Month', 'cryptlight' ),
	                ],
	                'default' 	=> 'quarter',
	            ]
	        );

	        $this->add_control(
	            'show_percentage',
	            [
	                'label' 	=> esc_html__( 'Show Percentage', 'cryptlight' ),
	                'type' 		=> Controls_Manager::SWITCHER,
	                'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
	                'condition' => [
	                    'type' 	=> 'v3',
	                ],
	            ]
	        );

	        $repeater = new \Elementor\Repeater();

	            $repeater->add_control(
					'percentage',
					[
						'label' 		=> esc_html__( 'Percentage', 'cryptlight' ),
						'type' 			=> Controls_Manager::TEXT,
						'default'		=> esc_html__( '', 'cryptlight' ),
						'description' 	=> esc_html__( 'Display in Type 3', 'cryptlight' )
					]
				);

				$repeater->add_control(
					'date',
					[
						'label' 		=> esc_html__( 'Date', 'cryptlight' ),
						'type' 			=> Controls_Manager::DATE_TIME,
						'default'		=> date( 'Y-m-d h:i', current_time('timestamp')),
						'description' 	=> sprintf( esc_html__( 'Date set according to your timezone: %s.', 'cryptlight' ), Utils::get_timezone_string() ),
					]
				);

				$repeater->add_control(
					'content',
					[
						'label' 		=> esc_html__( 'Content', 'cryptlight' ),
						'type' 			=> Controls_Manager::TEXTAREA,
						'default' 		=> esc_html__('Concepting idea, gathering people who deeply know about NFT and made a rock-solid team.', 'cryptlight' ),
					]
				);

				$repeater->add_control(
					'timeline_done',
					[
						'label' 	=> esc_html__( 'Timeline Done', 'cryptlight' ),
						'type' 		=> Controls_Manager::SWITCHER,
						'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
						'label_off' => esc_html__( 'No', 'cryptlight' ),
						'default' 	=> 'no',
					]
				);

				$repeater->add_responsive_control(
					'animation_content',
					[
						'label' => esc_html__( 'Animation Content', 'cryptlight' ),
						'type' 	=> Controls_Manager::ANIMATION,
					]
				);

				$repeater->add_control(
					'animation_duration_content',
					[
						'label' 	=> esc_html__( 'Animation Duration', 'cryptlight' ),
						'type' 		=> Controls_Manager::SELECT,
						'default' 	=> '',
						'options' 	=> [
							'slow' 	=> esc_html__( 'Slow', 'cryptlight' ),
							'' 		=> esc_html__( 'Normal', 'cryptlight' ),
							'fast' 	=> esc_html__( 'Fast', 'cryptlight' ),
						],
						'condition' => [
							'animation_content!' => '',
						],
					]
				);

				$repeater->add_control(
					'animation_delay_content',
					[
						'label' 	=> esc_html__( 'Animation Delay', 'cryptlight' ) . ' (ms)',
						'type' 		=> Controls_Manager::NUMBER,
						'default' 	=> '',
						'min' 		=> 0,
						'step' 		=> 100,
						'condition' => [
							'animation_content!' => '',
						],
					]
				);

			$this->add_control(
				'road_map_items',
				[
					'label' 	=> esc_html__( 'Items', 'cryptlight' ),
					'type' 		=> Controls_Manager::REPEATER,
					'fields' 	=> $repeater->get_controls(),
					'default' 	=> [
						[
							'percentage'       => esc_html__( '10', 'cryptlight' ),
							'date' 				=> esc_html__( '2021-03-01', 'cryptlight' ),
							'content' 			=> esc_html__('Concepting idea, gathering people who deeply know about NFT and made a rock-solid team', 'cryptlight' ),
							'timeline_done' 	=> 'yes',
						],
						[
							'percentage'   => esc_html__( '20', 'cryptlight' ),
							'date' 			=> esc_html__( '2021-05-01', 'cryptlight' ),
							'content' 		=> esc_html__('Collected a bunch of ideas for the CMC’s traits. The illustrator starts creating the characters. ', 'cryptlight' ),
							'timeline_done' => 'yes',
						],
						[
							'percentage'   => esc_html__( '30', 'cryptlight' ),
							'date' 			=> esc_html__( '2021-07-01', 'cryptlight' ),
							'content' 		=> esc_html__('Marketing team made a marketing strategy and built a community of people love our NFTs.', 'cryptlight' ),
							'timeline_done' => 'yes',
						],
						[
							'percentage'   => esc_html__( '40', 'cryptlight' ),
							'date' 			=> esc_html__( '2021-10-01', 'cryptlight' ),
							'content' 		=> esc_html__('In the last month of 2021, 2222 NFTs are distributed. Then, we will listing on marketplaces.', 'cryptlight' ),
							'timeline_done' => 'no',
						],
						[
							'percentage'   => esc_html__( '50', 'cryptlight' ),
							'date' 			=> esc_html__( '2022-01-01', 'cryptlight' ),
							'content' 		=> esc_html__('We will have new  members in the team to gather more ideas and develop our collection.', 'cryptlight' ),
							'timeline_done' => 'no',
						],
						[
							'percentage'   => esc_html__( '60', 'cryptlight' ),
							'date' 			=> esc_html__( '2022-04-01', 'cryptlight' ),
							'content' 		=> esc_html__('We will develop the rarity tools, implement premium features and suggestions from users.', 'cryptlight' ),
							'timeline_done' => 'no',
						],
					],
				]
			);
			
		$this->end_controls_section();

		/* Begin percentage v3 style */
		$this->start_controls_section(
			'percentage_style',
			[
				'label' 	=> esc_html__( 'Percentage', 'cryptlight' ),
				'tab'   	=> Controls_Manager::TAB_STYLE,
				'condition' => [
                    'type' 	=> 'v3',
                ],
			]
		);

		    $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'percentage_typography_v3',
					'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .date .percentage',
				]
			);

			$this->add_control(
				'percentage_color',
				[
					'label' 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .date .percentage' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'percentage_color_not_done',
				[
					'label' 	=> esc_html__( 'Color Not Done', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done .timeline-info .content-info .date .percentage' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'percentage_bgcolor',
				[
					'label' 	=> esc_html__( 'Background Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .date .percentage' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'percentage_bgcolor_not_done',
				[
					'label' 	=> esc_html__( 'Background Color Not Done', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done .timeline-info .content-info .date .percentage' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
	            'percentage_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .date .percentage' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'percentage_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .date .percentage' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

		$this->end_controls_section();
		/* End section percentage style */

		/* Begin section date style */
		$this->start_controls_section(
			'date_style',
			[
				'label' 	=> esc_html__( 'Date', 'cryptlight' ),
				'tab'   	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'date_color',
				[
					'label' 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left .timeline-info .content-info .date' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right .timeline-info .content-info .date' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .date' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .date' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'date_color_not_done',
				[
					'label' 	=> esc_html__( 'Color Not Done', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left.timeline-not-done .timeline-info .content-info .date' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right.timeline-not-done .timeline-info .content-info .date' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done .timeline-info .content-info .date' => 'color: {{VALUE}};',
					],
					'condition' => [
						'type' => ['v1', 'v2'],
					],
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'date_typography_v1',
					'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .date',
					'condition' => [
	                    'type' 	=> 'v1',
	                ],
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'date_typography_v2',
					'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .date',
					'condition' => [
	                    'type' 	=> 'v2',
	                ],
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'date_typography_v3',
					'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .date',
					'condition' => [
	                    'type' 	=> 'v3',
	                ],
				]
			);

		$this->end_controls_section();
		/* End section date style */

		/* Begin section icon style */
		$this->start_controls_section(
			'icon_style',
			[
				'label' 	=> esc_html__( 'Icon', 'cryptlight' ),
				'tab'   	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'icon_color',
				[
					'label' 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left .timeline-info:after' 	=> 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right .timeline-info:after' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info:after' 	=> 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info:after' 	=> 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'icon_bg',
				[
					'label' 	=> esc_html__( 'Background', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left .timeline-info:before' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right .timeline-info:before' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info:before' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info:before' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'icon_not_done_bg',
				[
					'label' 	=> esc_html__( 'Background Not Done', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-not-done .timeline-info:before' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-not-done .timeline-info:before' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-not-done .timeline-info:before' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'icon_not_done_bg_in',
				[
					'label' 	=> esc_html__( 'Background Not Done In', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left.timeline-not-done .timeline-info:after' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right.timeline-not-done .timeline-info:after' => 'background-color: {{VALUE}};',
					],
					'condition' => [
	                    'type' 	=> 'v1',
	                ],
				]
			);

			$this->add_control(
				'icon_border_option',
				[
					'label' 	=> esc_html__( 'Border Option', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

				$this->add_group_control(
		            Group_Control_Border::get_type(), [
		                'name' 		=> 'icon_done_border_v1',
		                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info:before',
		                'separator' => 'before',
		                'condition' => [
		                	'type' 	=> 'v1',
		                ],
		            ]
		        );

		        $this->add_group_control(
		            Group_Control_Border::get_type(), [
		                'name' 		=> 'icon_done_border_v2',
		                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info:before',
		                'separator' => 'before',
		                'condition' => [
		                	'type' 	=> 'v2',
		                ],
		            ]
		        );

		        $this->add_group_control(
		            Group_Control_Border::get_type(), [
		                'name' 		=> 'icon_done_border_v3',
		                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info:before',
		                'separator' => 'before',
		                'condition' => [
		                	'type' 	=> 'v3',
		                ],
		            ]
		        );

			$this->add_control(
				'icon_not_done_border_option',
				[
					'label' 	=> esc_html__( 'Border Not Done Option', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

				$this->add_group_control(
		            Group_Control_Border::get_type(), [
		                'name' 		=> 'icon_not_done_border_v1',
		                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-not-done .timeline-info:before',
		                'separator' => 'before',
		                'condition' => [
		                	'type' 	=> 'v1',
		                ],
		            ]
		        );

		        $this->add_group_control(
		            Group_Control_Border::get_type(), [
		                'name' 		=> 'icon_not_done_border_v2',
		                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-not-done .timeline-info:before',
		                'separator' => 'before',
		                'condition' => [
		                	'type' 	=> 'v2',
		                ],
		            ]
		        );

		        $this->add_group_control(
		            Group_Control_Border::get_type(), [
		                'name' 		=> 'icon_not_done_border_v3',
		                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-not-done .timeline-info:before',
		                'separator' => 'before',
		                'condition' => [
		                	'type' 	=> 'v3',
		                ],
		            ]
		        );

		$this->end_controls_section();
		/* End section icon style */

		/* Begin section icon style */
		$this->start_controls_section(
			'line_section_style',
			[
				'label' 	=> esc_html__( 'Line', 'cryptlight' ),
				'tab'   	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'line_border_option',
				[
					'label' 	=> esc_html__( 'Border Option', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

				$this->add_group_control(
		            Group_Control_Border::get_type(), [
		                'name' 		=> 'line_border',
		                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item:before, {{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item:before, {{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item:before',
		            ]
		        );

		    $this->add_control(
				'line_border_not_done_option',
				[
					'label' 	=> esc_html__( 'Border Not Done Option', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

		        $this->add_group_control(
		            Group_Control_Border::get_type(), [
		                'name' 		=> 'line_border_not_done',
		                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done:before, {{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done:before, {{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done:before',
		            ]
		        );

		$this->end_controls_section();
		/* End section icon style */

		/* Begin dotted line version 1, version 2 style */
		$this->start_controls_section(
			'dotted_line_style',
			[
				'label' 	=> esc_html__( 'Dotted Line', 'cryptlight' ),
				'tab'   	=> Controls_Manager::TAB_STYLE,
				'condition' => [
					'type' 	=> ['v1','v3']
				],
			]
		);

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'dotted_line_v1',
	                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .dotted-line',
	                'condition' => [
						'type' 	=> 'v1'
					],
	            ]
	        );

	        $this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'dotted_line_v3',
	                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .dotted-line',
	                 'condition' => [
						'type' 	=> 'v3'
					],
	            ]
	        );

	        $this->add_responsive_control(
	            'dotted_line_width',
	            [
	                'label' 		=> esc_html__( 'Width', 'cryptlight' ),
	                'type' 			=> Controls_Manager::SLIDER,
	                'size_units' 	=> [ 'px', '%' ],
	                'range' => [
						'px' => [
							'min' => 0,
							'max' => 150,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .dotted-line' => 'width: {{SIZE}}{{UNIT}}',
	                     '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .dotted-line' => 'width: {{SIZE}}{{UNIT}}',
	                ],
	            ]
	        );

		$this->end_controls_section();
		/* End dotted line version 1 */

		/* Begin section content style */
		$this->start_controls_section(
			'content_style',
			[
				'label' 	=> esc_html__( 'Content', 'cryptlight' ),
				'tab'   	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'content_color',
				[
					'label' 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left .timeline-info .timeline-content .content' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right .timeline-info .timeline-content .content' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .timeline-content .content' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .timeline-content .content' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'content_color_not_done',
				[
					'label' 	=> esc_html__( 'Color Not Done', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left.timeline-not-done .timeline-info .content-info .timeline-content .content' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right.timeline-not-done .timeline-info .content-info .timeline-content .content' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done .timeline-info .content-info .timeline-content .content' => 'color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done .timeline-info .content-info .timeline-content .content' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'content_line_color',
				[
					'label' 	=> esc_html__( 'Line Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left:before' 	=> 'border-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right:before' 	=> 'border-color: {{VALUE}};',
					],
					'condition' => [
	                    'type' 	=> 'v1',
	                ],
				]
			);

			$this->add_control(
				'content_line_color_not_done',
				[
					'label' 	=> esc_html__( 'Line Color Not Done', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left.timeline-not-done:before' 	=> 'border-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right.timeline-not-done:before' => 'border-color: {{VALUE}};',
					],
					'condition' => [
	                    'type' 	=> 'v1',
	                ],
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_v1',
					'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left .timeline-info .timeline-content .content',
					'condition' => [
	                    'type' 	=> 'v1',
	                ],
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_v2',
					'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .timeline-content .content',
					'condition' => [
	                    'type' 	=> 'v2',
	                ],
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'content_typography_v3',
					'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info .timeline-content .content',
					'condition' => [
	                    'type' 	=> 'v3',
	                ],
				]
			);

			$this->add_control(
				'content_bg',
				[
					'label' 	=> esc_html__( 'Background', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left .timeline-info .content-info' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right .timeline-info .content-info' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'content_bg_not_done',
				[
					'label' 	=> esc_html__( 'Background Not Done', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left.timeline-not-done .timeline-info .content-info' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right.timeline-not-done .timeline-info .content-info' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done .timeline-info .content-info' => 'background-color: {{VALUE}};',
						'{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done .timeline-info .content-info' => 'background-color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'content_border_left_option',
				[
					'label' 	=> esc_html__( 'Border Right Option', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
	                    'type' 	=> 'v1',
	                ],
				]
			);

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'content_border_left',
	                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left .timeline-info .content-info',
	                'separator' => 'before',
	                'condition' => [
	                    'type' 	=> 'v1',
	                ],
	            ]
	        );

	        $this->add_control(
				'content_left_color_not_done',
				[
					'label' 	=> esc_html__( 'Color Right Not Done', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left.timeline-not-done .timeline-info .content-info' => 'border-color: {{VALUE}};',
					],
					'condition' => [
	                    'type' 	=> 'v1',
	                ],
				]
			);

	        $this->add_control(
	            'content_border_radius_left',
	            [
	                'label' 		=> esc_html__( 'Border Right Radius', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left .timeline-info .content-info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	                'condition' => [
	                    'type' 	=> 'v1',
	                ],
	            ]
	        );

	        $this->add_control(
				'content_border_right_option',
				[
					'label' 	=> esc_html__( 'Border Left Option', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
	                    'type' 	=> 'v1',
	                ],
				]
			);

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'content_border_right',
	                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right .timeline-info .content-info',
	                'separator' => 'before',
	                'condition' => [
	                    'type' 	=> 'v1',
	                ],
	            ]
	        );

	        $this->add_control(
				'content_right_color_not_done',
				[
					'label' 	=> esc_html__( 'Color Left Not Done', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right.timeline-not-done .timeline-info .content-info' => 'border-color: {{VALUE}};',
					],
					'condition' => [
	                    'type' 	=> 'v1',
	                ],
				]
			);

	        $this->add_control(
	            'content_border_radius_right',
	            [
	                'label' 		=> esc_html__( 'Border Left Radius', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right .timeline-info .content-info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	                'condition' => [
	                    'type' 	=> 'v1',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'content_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	                'condition' => [
	                    'type' 	=> ['v2','v3']
	                ],
	            ]
	        );

			$this->add_responsive_control(
	            'content_padding',
	            [
	                'label' 		=> esc_html__( 'Padding', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left .timeline-info .content-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right .timeline-info .content-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'content_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-left .timeline-info .content-info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item-right .timeline-info .content-info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                     '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item .timeline-info .content-info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );
            
            // content border style v3
	        $this->add_control(
				'content_border_v2_heading',
				[
					'label' => esc_html__( 'Content Border', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
	                	'type' 	=> 'v2',
	                ],
				]
			);

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'content_border_v2',
	                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-info .content-info',
	                'separator' => 'before',
	                'condition' => [
	                	'type' 	=> 'v2',
	                ],
	            ]
	        );

			$this->add_control(
				'content_border_not_done_v2_heading',
				[
					'label' => esc_html__( 'Content Border Not Done', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
	                	'type' 	=> 'v2',
	                ],
				]
			);

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'content_border_not_done_v2',
	                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done .timeline-info .content-info',
	                'separator' => 'before',
	                'condition' => [
	                	'type' 	=> 'v2',
	                ],
	            ]
	        );
            
            // content border style v3
			$this->add_control(
				'content_border_v3_heading',
				[
					'label' => esc_html__( 'Content Border', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
	                	'type' 	=> 'v3',
	                ],
				]
			);

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'content_border_v3',
	                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-info .content-info',
	                'separator' => 'before',
	                'condition' => [
	                	'type' 	=> 'v3',
	                ],
	            ]
	        );

			$this->add_control(
				'content_border_not_done_v3_heading',
				[
					'label' => esc_html__( 'Content Border Not Done', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
	                	'type' 	=> 'v3',
	                ],
				]
			);

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'content_border_not_done_v3',
	                'selector' 	=> '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item.timeline-not-done .timeline-info .content-info',
	                'separator' => 'before',
	                'condition' => [
	                	'type' 	=> 'v3',
	                ],
	            ]
	        );

		$this->end_controls_section();
		/* End section content style */

		/* Begin section item style */
		$this->start_controls_section(
			'item_style',
			[
				'label' 	=> esc_html__( 'Item', 'cryptlight' ),
				'tab'   	=> Controls_Manager::TAB_STYLE,
			]
		);

		    $this->add_responsive_control(
	            'item_space_between',
	            [
	                'label' 		=> esc_html__( 'Space Between', 'cryptlight' ),
	                'type' 			=> Controls_Manager::SLIDER,
	                'size_units' 	=> [ 'px', '%'],
	                'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-road-map-2-v1 .road-map-2-wrapper .timeline-column .timeline-item:not(:last-child)' => 'padding-bottom:{{SIZE}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-road-map-2-v2 .road-map-2-wrapper .timeline-column .timeline-item' => 'padding-bottom:{{SIZE}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-road-map-2-v3 .road-map-2-wrapper .timeline-column .timeline-item:not(:last-child)' => 'padding-bottom:{{SIZE}}{{UNIT}};',
	                ],
	            ]
	        );

		$this->end_controls_section();
		/* End section item style */
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$type 		      = $settings['type'];
		$date_format      = $settings['date_format'];
		$show_percentage  = $settings['show_percentage'];

		// version 1
		$road_map 	= $settings['road_map_items'];

		 ?>

		<div class="ova-road-map-2-<?php echo esc_html( $type ); ?>">
			<div class="road-map-2-wrapper">
				<?php if ( ! empty( $road_map ) ): ?>
					<div class="timeline-column">
						<?php foreach ( $road_map as $k => $items ): 
							$time_stamp 	= strtotime( $items['date'] );
							$month 			= date_i18n('F', $time_stamp);
							$month_quarter  = date_i18n('n', $time_stamp);
							$year 			= date_i18n('Y', $time_stamp);
							$content 		= $items['content'];
							$timeline_done 	= $items['timeline_done'];
							$percentage     = $items['percentage'];
							$timeline_check = 'timeline-not-done';
							if ( 'yes' == $timeline_done ) {
								$timeline_check = '';
							}

                            // get quarter
						    if ($month_quarter <= 3) {
						    	$month_quarter = 'Q1';
						    } elseif($month_quarter <= 6) {
						        $month_quarter  = 'Q2';
						    } elseif($month_quarter <= 9) {
						        $month_quarter  = 'Q3';
						    } else{
						        $month_quarter  = 'Q4';
						    }

							//Animation Content
							$animation_content 	= $items['animation_content'];
							$duration_content 	= $items['animation_duration_content'];
							$delay_content		= $items['animation_delay_content'];

							$data_animation_content = array(
								'animation' => $animation_content,
								'duration' 	=> $duration_content,
								'delay' 	=> $delay_content,
							);
						?>

						<?php if ( 'v1' == $type ): ?>
							<?php if ( $k % 2 == 0 ): ?>
								<div class="timeline-item timeline-item-left <?php echo esc_html( $timeline_check ); ?>">
									<div class="timeline-info">
										<div class="dotted-line"></div>
										<div 
											class="content-info<?php if ( $animation_content ) echo ' ova-invisible'; ?>" 
											data-animation='<?php echo json_encode( $data_animation_content ); ?>'>

											<div class="date">
												<?php 
												    if ($date_format === 'quarter') {
                                                        echo esc_html( $month_quarter . ' ' . $year ); 
                                                    } else {
                                                        echo esc_html( $month . ' ' . $year );
                                                    }
												?>	
											</div>
											<div class="timeline-content">
												<p class="content"><?php echo esc_html( $content ); ?></p>
											</div>
										</div>
									</div>
								</div>
							<?php else: ?>
								<div class="timeline-item timeline-item-right <?php echo esc_html( $timeline_check ); ?>">
									<div class="timeline-info">
										<div class="dotted-line"></div>
										<div 
											class="content-info<?php if ( $animation_content ) echo ' ova-invisible'; ?>" 
											data-animation='<?php echo json_encode( $data_animation_content ); ?>'>

											<div class="date">
												<?php 
												    if ($date_format === 'quarter') {
                                                        echo esc_html( $month_quarter . ' ' . $year ); 
                                                    } else {
                                                        echo esc_html( $month . ' ' . $year );
                                                    }
												?>	
											</div>
											<div class="timeline-content">
												<p class="content"><?php echo esc_html( $content ); ?></p>
											</div>
										</div>
									</div>
								</div>
					        <?php  endif; ?>
					    <!-- Version 2 -->
					    <?php  elseif( 'v2' == $type ): ?>
                            <div class="timeline-item <?php echo esc_html( $timeline_check ); ?>">
								<div class="timeline-info">
									<div 
										class="content-info<?php if ( $animation_content ) echo ' ova-invisible'; ?>" 
										data-animation='<?php echo json_encode( $data_animation_content ); ?>'>

										<div class="date">
											<?php 
											    if ($date_format === 'quarter') {
                                                    echo esc_html( $month_quarter . ' ' . $year ); 
                                                } else {
                                                    echo esc_html( $month . ' ' . $year );
                                                }
											?>	
										</div>
										<div class="timeline-content">
											<p class="content"><?php echo esc_html( $content ); ?></p>
										</div>
									</div>
								</div>
							</div>
					   
					    <!-- End Version 2 -->
					    <!-- Start Version 3 -->
					    <?php elseif ( 'v3' == $type ): ?>
							<?php if ( $k % 2 == 0 ): ?>
								<div class="timeline-item timeline-item-left <?php echo esc_html( $timeline_check ); ?>">
									<div class="timeline-info">
										<div class="dotted-line"></div>
										<div 
											class="content-info<?php if ( $animation_content ) echo ' ova-invisible'; ?>" 
											data-animation='<?php echo json_encode( $data_animation_content ); ?>'>

											<div class="date">
												<?php if( $show_percentage === 'yes' && $percentage != '' ) : ?>
												    <div class="percentage">
												    	<?php echo esc_html( $percentage . '%' ); ?>
												    </div>
											    <?php endif;?>
												<?php 
												    if ($date_format === 'quarter') {
                                                        echo esc_html( $month_quarter . ' ' . $year ); 
                                                    } else {
                                                        echo esc_html( $month . ' ' . $year );
                                                    }
												?>	
											</div>
											<div class="timeline-content">
												<p class="content"><?php echo esc_html( $content ); ?></p>
											</div>
										</div>
									</div>
								</div>
							<?php else: ?>
								<div class="timeline-item timeline-item-right <?php echo esc_html( $timeline_check ); ?>">
									<div class="timeline-info">
										<div class="dotted-line"></div>
										<div 
											class="content-info<?php if ( $animation_content ) echo ' ova-invisible'; ?>" 
											data-animation='<?php echo json_encode( $data_animation_content ); ?>'>

											<div class="date">
												<?php if( $show_percentage === 'yes' && $percentage != '' ) : ?>
												    <div class="percentage">
												    	<?php echo esc_html( $percentage . '%'); ?>
												    </div>
											    <?php endif;?>
												<?php 
												    if ($date_format === 'quarter') {
                                                        echo esc_html( $month_quarter . ' ' . $year ); 
                                                    } else {
                                                        echo esc_html( $month . ' ' . $year );
                                                    }
												?>	
											</div>
											<div class="timeline-content">
												<p class="content"><?php echo esc_html( $content ); ?></p>
											</div>
										</div>
									</div>
								</div>
					        <?php  endif; ?>
					    <?php  endif; ?>
					     <!-- End Version 3 -->
					    <?php endforeach; ?>
				    </div>
			    <?php  endif; ?>
			</div>
		</div>

		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Road_Map_2() );