<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Cryptlight_Elementor_Simple_Image_Box extends Widget_Base {

	
	public function get_name() {
		return 'cryptlight_elementor_simple_image_box';
	}

	
	public function get_title() {
		return esc_html__( 'Simple Image Box', 'cryptlight' );
	}

	
	public function get_icon() {
		return 'eicon-image';
	}

	
	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'cryptlight' ),
			]
		);	
				
			// Add Class control
			$this->add_control(
				'image',
				[
					'label'   => esc_html__( 'Choose Image', 'cryptlight' ),
					'type'    => Controls_Manager::MEDIA,
					'default' => [
						'url' => Utils::get_placeholder_image_src(),
					],
				]
			);

			$this->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'cryptlight' ),
					'type' => Controls_Manager::URL,
					'dynamic' => [
						'active' => true,
					],
					'placeholder' => esc_html__( 'https://your-link.com', 'cryptlight' ),
					'show_label' => true,
					'default' => [
						'url' => '',
					],
				]
			);

            $this->add_control(
				'caption',
				[
					'label' => esc_html__( 'Caption', 'cryptlight' ),
					'type' => Controls_Manager::TEXTAREA,
					'default' => esc_html__( ' Fantasy world in your eyes.', 'cryptlight' ),
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_caption',
			[
				'label' => esc_html__( 'Caption', 'cryptlight' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'caption_typography',
					'selector' => '{{WRAPPER}} .ova-simple-image-box .caption',
				]
			);

			$this->add_responsive_control(
				'caption_align',
				[
					'label' 	=> esc_html__( 'Alignment', 'cryptlight' ),
					'type' 		=> Controls_Manager::CHOOSE,
					'options' 	=> [
						'left' 	=> [
							'title' => esc_html__( 'Left', 'cryptlight' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'cryptlight' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'cryptlight' ),
							'icon' 	=> 'eicon-text-align-right',
						],
						'justify' => [
							'title' => esc_html__( 'Justified', 'cryptlight' ),
							'icon' 	=> 'eicon-text-align-justify',
						],
					],
					'default' 	=> '',
					'selectors' => [
						'{{WRAPPER}} .ova-simple-image-box .caption'=> 'text-align: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'caption_color',
				[
					'label'     => esc_html__( 'Color', 'cryptlight' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-simple-image-box .caption' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'line_color',
				[
					'label'     => esc_html__( 'Line Color', 'cryptlight' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-simple-image-box:before' => 'background-color : {{VALUE}};',
					],
				]
			);
            
            $this->add_responsive_control(
				'caption_padding',
				[
					'label'      => esc_html__( 'Padding', 'cryptlight' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-simple-image-box .caption' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		 // Get url image
		$url 	= $settings['image']['url'];
		$alt 	= isset( $settings['image']['alt'] ) ? $settings['image']['alt'] : '';
		
		if ( empty( $url ) ) {
			return;
		}

		$link        = $settings['link'];
		$nofollow    = ( isset( $link['nofollow'] ) && $link['nofollow'] ) ? ' rel="nofollow"' : '';
		$target      = ( isset( $link['is_external'] ) && $link['is_external'] !== '' ) ? ' target="_blank"' : '';

		$caption		= $settings['caption'];

		if ( empty( $alt ) ) {
			$alt = $caption ? $caption : esc_html__( 'Avatar', 'cryptlight' );
		}

		 ?>

        <?php if ( !empty($link['url'])) : ?>	
		<a href="<?php echo esc_url( $link['url'] ); ?> "  <?php echo esc_attr( $target ); ?> <?php echo esc_attr( $nofollow ); ?>>
	    <?php endif; ?>

			<div class="ova-simple-image-box">
				<img src="<?php echo esc_url( $url ); ?>" class="box-img" alt="<?php echo esc_attr( $alt ); ?>">
				<?php if ( ! empty ( $caption ) ): ?>
					<p  class="caption">
						<?php echo esc_html( $caption ); ?>
					</p>
				<?php endif; ?>
			</div>

	    <?php if ( !empty($link['url']) ) : ?>
	        </a>
        <?php endif; ?>

		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Simple_Image_Box() );