<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Cryptlight_Elementor_Simple_Image_Carousel extends Widget_Base {

	
	public function get_name() {
		return 'cryptlight_elementor_simple_image_carousel';
	}

	
	public function get_title() {
		return esc_html__( 'Simple Image Carousel', 'cryptlight' );
	}

	
	public function get_icon() {
		return 'eicon-carousel';
	}

	
	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		wp_enqueue_style( 'carousel', get_template_directory_uri().'/assets/libs/carousel/assets/owl.carousel.min.css' );
		wp_enqueue_script( 'carousel', get_template_directory_uri().'/assets/libs/carousel/owl.carousel.min.js', array('jquery'), false, true );
		return [ 'cryptlight-elementor-simple-image-carousel' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'cryptlight' ),
			]
		);	

		    $this->add_control(
	            'type',
	            [
	                'label' 	=> esc_html__( 'Type', 'cryptlight' ),
	                'type' 		=> Controls_Manager::SELECT,
	                'options' 	=> [
	                    'v1' => esc_html__( 'Type 1', 'cryptlight' ),
	                    'v2' => esc_html__( 'Type 2', 'cryptlight' ),
	                ],
	                'default' 	=> 'v1',
	            ]
	        );
				
			// Add Class control
		    $repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'image',
				[
					'label'   => esc_html__( 'Choose Image', 'cryptlight' ),
					'type'    => Controls_Manager::MEDIA,
					'default' => [
						'url' => Utils::get_placeholder_image_src(),
					],
				]
			);

			$repeater->add_control(
				'link',
				[
					'label' => esc_html__( 'Link', 'cryptlight' ),
					'type' => Controls_Manager::URL,
					'dynamic' => [
						'active' => true,
					],
					'placeholder' => esc_html__( 'https://your-link.com', 'cryptlight' ),
					'show_label' => true,
					'default' => [
						'url' => '',
					],
				]
			);

            $repeater->add_control(
				'caption',
				[
					'label' => esc_html__( 'Caption', 'cryptlight' ),
					'type' => Controls_Manager::TEXT,
					'default' => esc_html__( 'Habitant turpis.', 'cryptlight' ),
				]
			);

			$repeater->add_responsive_control(
				'background_color',
				[
					'label' 		=> esc_html__( 'Background', 'cryptlight' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'.ova-simple-image-carousel .simple-image-carousel {{CURRENT_ITEM}} .simple-image-carousel-img' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'tab_item',
				[
					'label'		=> esc_html__( 'Tabs', 'cryptlight' ),
					'type'		=> Controls_Manager::REPEATER,
					'fields'  	=> $repeater->get_controls(),
					'default' 	=> [
						[
							'caption' => esc_html__('Habitant turpis.', 'cryptlight'),
						],
						[
							'caption' => esc_html__('Habitant turpis.', 'cryptlight'),
						],
						[
							'caption' => esc_html__('Habitant turpis.', 'cryptlight'),
						],
						[
							'caption' => esc_html__('Habitant turpis.', 'cryptlight'),
						],
						[
							'caption' => esc_html__('Habitant turpis.', 'cryptlight'),
						],
					],
				]
			);

		$this->end_controls_section();

		/*****************************************************************
						START SECTION ADDITIONAL
		******************************************************************/

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options', 'cryptlight' ),
			]
		);

			$this->add_control(
				'margin_items',
				[
					'label'   => esc_html__( 'Margin Right Items', 'cryptlight' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 12,
				]
				
			);

			$this->add_control(
				'stagePadding',
				[
					'label'   => esc_html__( 'stagePadding', 'cryptlight' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 60,
				]
				
			);

			$this->add_control(
				'item_number',
				[
					'label'       => esc_html__( 'Item Number', 'cryptlight' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'cryptlight' ),
					'default'     => 4,
				]
			);

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'cryptlight' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'cryptlight' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'cryptlight' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);


			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'cryptlight' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'cryptlight' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'cryptlight' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 2000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => false,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'cryptlight' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 2000,
				]
			);

			$this->add_control(
				'nav_control',
				[
					'label'   => esc_html__( 'Show Nav', 'cryptlight' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'rtl',
				[
					'label'   => esc_html__( 'Right to Left', 'cryptlight' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

		$this->end_controls_section();

		/****************************  END SECTION ADDITIONAL *********************/

		$this->start_controls_section(
			'section_caption',
			[
				'label' => esc_html__( 'Caption', 'cryptlight' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name'     => 'caption_typography',
					'selector' => '{{WRAPPER}} .ova-simple-image-carousel .simple-image-carousel .item .caption',
				]
			);

			$this->add_control(
				'caption_color',
				[
					'label'     => esc_html__( 'Color', 'cryptlight' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-simple-image-carousel .simple-image-carousel .item .caption' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'line_color',
				[
					'label'     => esc_html__( 'Line Color', 'cryptlight' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-simple-image-carousel .simple-image-carousel .item .caption .line' => 'background-color : {{VALUE}};',
					],
					'condition' => [
						'type' => 'v2'
					]
				]
			);
            
            $this->add_responsive_control(
				'caption_padding',
				[
					'label'      => esc_html__( 'Padding', 'cryptlight' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors'  => [
						'{{WRAPPER}} .ova-simple-image-carousel .simple-image-carousel .item .caption' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_image_style',
			[
				'label' => esc_html__( 'Image', 'cryptlight' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'image_height',
				[
					'label' 	=> esc_html__( 'Height', 'cryptlight' ),
					'type' 		=> Controls_Manager::SLIDER,
					'size_units' 	=> [ '%', 'px' ],
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'range' => [
						'px' => [
							'min' => 180,
							'max' => 450,
						],
					],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-simple-image-carousel .simple-image-carousel .item .simple-image-carousel-img img' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

        $type     = $settings['type'];
		$tab_item = $settings['tab_item'];

		$data_options['items']              = $settings['item_number'];
		$data_options['slideBy']            = $settings['slides_to_scroll'];
		$data_options['margin']             = $settings['margin_items'];
		$data_options['stagePadding']       = $settings['stagePadding'];
		$data_options['autoplayHoverPause'] = $settings['pause_on_hover'] === 'yes' ? true : false;
		$data_options['loop']               = $settings['infinite'] === 'yes' ? true : false;
		$data_options['autoplay']           = $settings['autoplay'] === 'yes' ? true : false;
		$data_options['autoplayTimeout']    = $settings['autoplay_speed'];
		$data_options['smartSpeed']         = $settings['smartspeed'];
		$data_options['nav']                = $settings['nav_control'] === 'yes' ? true : false;
		$data_options['rtl']				= $settings['rtl'] === 'yes' ? true: false;

		 ?>
            
            <div class="ova-simple-image-carousel <?php echo esc_attr( $type ); ?>">

				<div class="simple-image-carousel owl-carousel owl-theme" data-options="<?php echo esc_attr(json_encode($data_options)) ?>">
					<?php if(!empty($tab_item)) : foreach ($tab_item as $items) : 

					    $item_id 	= 'elementor-repeater-item-' . $items['_id'];
						$img_url 	 = $items['image']['url'];
						$img_alt 	 = isset( $items['image']['alt'] ) ? $items['image']['alt'] : esc_html__('Simple Image Carousel','cryptlight');
						$caption     = $items['caption'];
						$link        = $items['link'];
						$nofollow    = ( isset( $link['nofollow'] ) && $link['nofollow'] ) ? ' rel="nofollow"' : '';
						$target      = ( isset( $link['is_external'] ) && $link['is_external'] !== '' ) ? ' target="_blank"' : '';
						?>

							<div class="item <?php echo esc_attr( $item_id ); ?>">

								<?php if ( !empty($link['url'])) : ?>	
								<a href="<?php echo esc_url( $link['url'] ); ?> "  <?php echo esc_attr( $target ); ?> <?php echo esc_attr( $nofollow ); ?>>
							    <?php endif; ?>

									<div class="simple-image-carousel-img">
										<img src="<?php echo esc_url( $img_url ); ?>" alt="<?php echo esc_attr( $img_alt ); ?>">
									</div>

								<?php if ( !empty($link['url']) ) : ?>
							        </a>
						        <?php endif; ?>

								<?php if ( !empty ($caption)) : ?>
									<div class="caption">
										<?php if ( $type === 'v2') : ?>
										    <span class="line"></span>
										<?php endif; ?>
										<?php echo esc_html($caption); ?>
									</div>
								<?php endif; ?>

							</div>
								
					<?php endforeach; endif; ?>

				</div>

			</div>
	 	
		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Simple_Image_Carousel() );