<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Cryptlight_Elementor_Team_Slider_2 extends Widget_Base {

	
	public function get_name() {
		return 'cryptlight_elementor_team_slider_2';
	}

	
	public function get_title() {
		return esc_html__( 'Team Slider 2', 'cryptlight' );
	}

	
	public function get_icon() {
		return 'eicon-user-circle-o';
	}

	
	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		wp_enqueue_style( 'carousel', get_theme_file_uri('/assets/libs/carousel/assets/owl.carousel.min.css') );
		wp_enqueue_script( 'carousel', get_theme_file_uri('/assets/libs/carousel/owl.carousel.min.js'), array('jquery'), false, true );
		return [ 'cryptlight-elementor-team-slider-2' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_team_slider_2',
			[
				'label' => esc_html__( 'Team Slider 2', 'cryptlight' ),
			]
		);	

		    $this->add_control(
	            'type',
	            [
	                'label' 	=> esc_html__( 'Type', 'cryptlight' ),
	                'type' 		=> Controls_Manager::SELECT,
	                'options' 	=> [
	                    'v1' => esc_html__( 'Type 1', 'cryptlight' ),
	                    'v2' => esc_html__( 'Type 2', 'cryptlight' ),
	                ],
	                'default' 	=> 'v1',
	            ]
	        );
			
			$repeater = new \Elementor\Repeater();

				$repeater->add_control(
					'avatar',
					[
						'label' 	=> esc_html__( 'Choose Avatar', 'cryptlight' ),
						'type' 		=> Controls_Manager::MEDIA,
						'default' 	=> [
							'url' 	=> Utils::get_placeholder_image_src(),
						],
					]
				);

				$repeater->add_control(
					'name',
					[
						'label' 		=> esc_html__( 'Name', 'cryptlight' ),
						'type' 			=> Controls_Manager::TEXT,
						'default' 		=> esc_html__('Add Your Name', 'cryptlight' ),
					]
				);

				$repeater->add_control(
					'job',
					[
						'label' 		=> esc_html__( 'Job', 'cryptlight' ),
						'type' 			=> Controls_Manager::TEXT,
						'default' 		=> esc_html__('Add Your Job', 'cryptlight' ),
					]
				);

				$repeater->add_control(
					'link',
					[
						'label' 		=> esc_html__( 'Link', 'cryptlight' ),
						'type' 			=> Controls_Manager::URL,
						'placeholder' 	=> esc_html__( 'https://your-link.com', 'cryptlight' ),
						'show_external' => true,
					]
				);

			$this->add_control(
				'team_slider_items',
				[
					'label' 	=> esc_html__( 'Items', 'cryptlight' ),
					'type' 		=> Controls_Manager::REPEATER,
					'fields' 	=> $repeater->get_controls(),
					'default' 	=> [
						[
							'avatar' 		=> [ 'url' => Utils::get_placeholder_image_src() ],
							'name' 			=> esc_html__('Jane Cooper', 'cryptlight' ),
							'job' 			=> esc_html__('Designer', 'cryptlight' ),
						],
						[
							'avatar' 		=> [ 'url' => Utils::get_placeholder_image_src() ],
							'name' 			=> esc_html__('Theresa Webb', 'cryptlight' ),
							'job' 			=> esc_html__('Artist', 'cryptlight' ),
						],
						[
							'avatar' 		=> [ 'url' => Utils::get_placeholder_image_src() ],
							'name' 			=> esc_html__('Dianne Russell', 'cryptlight' ),
							'job' 			=> esc_html__('Developer', 'cryptlight' ),
						],
						[
							'avatar' 		=> [ 'url' => Utils::get_placeholder_image_src() ],
							'name' 			=> esc_html__('Brooklyn Simmons', 'cryptlight' ),
							'job' 			=> esc_html__('Game developer', 'cryptlight' ),
						],
						[
							'avatar' 		=> [ 'url' => Utils::get_placeholder_image_src() ],
							'name' 			=> esc_html__('Ralph Edwards', 'cryptlight' ),
							'job' 			=> esc_html__('Co-founder', 'cryptlight' ),
						]
					],
					'title_field' => '{{{ name }}}',
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_additional_options',
			[
				'label' => esc_html__( 'Additional Options', 'cryptlight' ),
			]
		);

			$this->add_control(
				'margin_items',
				[
					'label'   => esc_html__( 'Margin Right Items', 'cryptlight' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 63,
				]
				
			);

			$this->add_control(
				'item_number',
				[
					'label'       => esc_html__( 'Item Number', 'cryptlight' ),
					'type'        => Controls_Manager::NUMBER,
					'default'     => 4,
				]
			);

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'cryptlight' ),
					'type'        => Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'cryptlight' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'cryptlight' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'cryptlight' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'cryptlight' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'cryptlight' ),
					'type'      => Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoWidth',
				[
					'label'   => esc_html__( 'AutoWidth', 'cryptlight' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'no',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'cryptlight' ),
					'type'    => Controls_Manager::NUMBER,
					'default' => 500,
				]
			);

			$this->add_control(
				'nav_control',
				[
					'label'   => esc_html__( 'Show Nav', 'cryptlight' ),
					'type'    => Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'nav_left',
				[
					'label'       	=> esc_html__( 'Icon Left', 'cryptlight' ),
					'type'        	=> Controls_Manager::TEXT,
					'default'     	=> esc_html__( 'iconly-Arrow-Left-2 icli', 'cryptlight' ),
					'condition' 	=> [
						'nav_control' => 'yes',
					],
				]
			);

			$this->add_control(
				'nav_right',
				[
					'label'       	=> esc_html__( 'Icon Right', 'cryptlight' ),
					'type'        	=> Controls_Manager::TEXT,
					'default'     	=> esc_html__( 'iconly-Arrow-Right-2 icli', 'cryptlight' ),
					'condition' 	=> [
						'nav_control' => 'yes',
					],
				]
			);

		$this->end_controls_section();

		/* Begin Avatar Style */
		$this->start_controls_section(
            'avatar_style',
            [
                'label' => esc_html__( 'Avatar', 'cryptlight' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

        	$this->add_responsive_control(
				'image_width',
				[
					'label' 	=> esc_html__( 'Width', 'cryptlight' ),
					'type' 		=> Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'tablet_default' => [
						'unit' => 'px',
					],
					'mobile_default' => [
						'unit' => 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
						'vw' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px', '%', 'vw' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .avatar' => 'width: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .avatar img' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'image_max_width',
				[
					'label' 	=> esc_html__( 'Max Width', 'cryptlight' ),
					'type' 		=> Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'tablet_default' => [
						'unit' => 'px',
					],
					'mobile_default' => [
						'unit' => 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
						'vw' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px', '%', 'vw' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .avatar' => 'max-width: {{SIZE}}{{UNIT}}',
						'{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .avatar img' => 'max-width: {{SIZE}}{{UNIT}}',
					],
				]
			);

			$this->add_responsive_control(
				'image_height',
				[
					'label' 	=> esc_html__( 'Height', 'cryptlight' ),
					'type' 		=> Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> 'px',
					],
					'tablet_default' => [
						'unit' => 'px',
					],
					'mobile_default' => [
						'unit' => 'px',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
						'vh' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px', '%', 'vh' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .avatar' => 'height: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .avatar img' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
	            'frame_color',
	            [
	                'label' 	=> esc_html__( 'Frame Border Color', 'cryptlight' ),
	                'type' 		=> Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .avatar:before' => 'border-color: {{VALUE}}',
	                ],
	                'condition' => [
	                	'type' => 'v1'
	                ]
	            ]
	        );

			$this->add_responsive_control(
	            'avatar_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .avatar' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-team-slider-2-v2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .avatar' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
        /* End Avatar Style */

        /* Begin Name Style */
		$this->start_controls_section(
            'name_style',
            [
                'label' => esc_html__( 'Name', 'cryptlight' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

        	$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'name_v1_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .name',
					'condition' => [
						'type' => 'v1'
					]
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'name_v2_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team-slider-2-v2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .info .name',
					'condition' => [
						'type' => 'v2'
					]
				]
			);

			$this->start_controls_tabs( 'tabs_name_style' );

				$this->start_controls_tab(
		            'tab_name_normal',
		            [
		                'label' => esc_html__( 'Normal', 'cryptlight' ),
		            ]
		        );

					$this->add_control(
			            'name_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .name' => 'color: {{VALUE}}',
			                    '{{WRAPPER}} .ova-team-slider-2-v2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .info .name' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();

				$this->start_controls_tab(
		            'tab_name_hover',
		            [
		                'label' => esc_html__( 'Hover', 'cryptlight' ),
		            ]
		        );

					$this->add_control(
			            'name_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items:hover .name' => 'color: {{VALUE}}',
			                    '{{WRAPPER}} .ova-team-slider-2-v2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items:hover .info .name' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_responsive_control(
	            'name_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-team-slider-2-v2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .info .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
        /* End Name Style */

        /* Begin Job Style */
		$this->start_controls_section(
            'job_style',
            [
                'label' => esc_html__( 'Job', 'cryptlight' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

        	$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'job_v1_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .job',
					'condition' => [
						'type' => 'v1'
					]
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'job_v2_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team-slider-2-v2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .info .job',
					'condition' => [
						'type' => 'v2'
					]
				]
			);

			$this->start_controls_tabs( 'tabs_job_style' );

				$this->start_controls_tab(
		            'tab_job_normal',
		            [
		                'label' => esc_html__( 'Normal', 'cryptlight' ),
		            ]
		        );

					$this->add_control(
			            'job_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .job' => 'color: {{VALUE}}',
			                    '{{WRAPPER}} .ova-team-slider-2-v2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .info .job' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();

				$this->start_controls_tab(
		            'tab_job_hover',
		            [
		                'label' => esc_html__( 'Hover', 'cryptlight' ),
		            ]
		        );

					$this->add_control(
			            'job_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items:hover .job' => 'color: {{VALUE}}',
			                    '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items:hover .info .job' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

				$this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_responsive_control(
	            'job_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider-2-v1 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .job' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                    '{{WRAPPER}} .ova-team-slider-2-v2 .team-slider-2-wrapper.owl-carousel .owl-stage-outer .owl-stage .owl-item .items .info .job' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
        /* End Job Style */

         /* Begin Nav Style */
		$this->start_controls_section(
            'nav_style',
            [
                'label' => esc_html__( 'Nav', 'cryptlight' ),
                'tab' 	=> Controls_Manager::TAB_STYLE,
            ]
        );

        	$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'nav_typography',
					'selector' 	=> '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button i',
				]
			);

			$this->add_responsive_control(
				'nav_size',
				[
					'label' 	=> esc_html__( 'Size', 'cryptlight' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};min-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'nav_left_position',
				[
					'label' 	=> esc_html__( 'Left Position', 'cryptlight' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => -500,
							'max' => 500,
						],
					],
					'size_units' 	=> [ 'px', '%' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team-slider-2-v2 .team-slider-2-wrapper.owl-carousel .owl-nav' => 'left: {{SIZE}}{{UNIT}}',
					],
					'condition' => [
						'type' => 'v2'
					]
				]
			);

			$this->add_responsive_control(
				'nav_top_position',
				[
					'label' 	=> esc_html__( 'Top Position', 'cryptlight' ),
					'type' 		=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => -500,
							'max' => 500,
						],
					],
					'size_units' 	=> [ 'px', '%' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-team-slider-2-v2 .team-slider-2-wrapper.owl-carousel .owl-nav' => 'top: {{SIZE}}{{UNIT}}',
					],
					'condition' => [
						'type' => 'v2'
					]
				]
			);

			$this->start_controls_tabs( 'tabs_nav_style' );

				$this->start_controls_tab(
		            'tab_nav_normal',
		            [
		                'label' => esc_html__( 'Normal', 'cryptlight' ),
		            ]
		        );

					$this->add_control(
			            'nav_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button i' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

			        $this->add_group_control(
						Group_Control_Background::get_type(),
						[
							'name' 		=> 'nav_background_normal',
							'label' 	=> esc_html__( 'Background', 'cryptlight' ),
							'types' 	=> [ 'classic', 'gradient' ],
							'exclude' 	=> [ 'image' ],
							'selector' 	=> '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button',
						]
					);

					$this->add_control(
						'nav_opacity_normal',
						[
							'label' 		=> esc_html__( 'Opacity', 'cryptlight' ),
							'type' 			=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' 	=> 0,
									'max' 	=> 1,
									'step' 	=> 0.1,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button' => 'opacity: {{SIZE}}',
							],
						]
					);

				$this->end_controls_tab();

				$this->start_controls_tab(
		            'tab_nav_hover',
		            [
		                'label' => esc_html__( 'Hover', 'cryptlight' ),
		            ]
		        );

					$this->add_control(
			            'nav_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button:hover i' => 'color: {{VALUE}}',
			                ],
			            ]
			        );

			        $this->add_group_control(
						Group_Control_Background::get_type(),
						[
							'name' 		=> 'nav_background_hover',
							'label' 	=> esc_html__( 'Background', 'cryptlight' ),
							'types' 	=> [ 'classic', 'gradient' ],
							'exclude' 	=> [ 'image' ],
							'selector' 	=> '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button:hover',
						]
					);

					$this->add_control(
			            'nav_border_color_hover',
			            [
			                'label' 	=> esc_html__( 'Border Color Hover', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button:hover' => 'border-color: {{VALUE}}',
			                ],
			            ]
			        );

					$this->add_control(
						'nav_opacity_hover',
						[
							'label' 		=> esc_html__( 'Opacity', 'cryptlight' ),
							'type' 			=> Controls_Manager::SLIDER,
							'range' => [
								'px' => [
									'min' 	=> 0,
									'max' 	=> 1,
									'step' 	=> 0.1,
								],
							],
							'selectors' => [
								'{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button:hover' => 'opacity: {{SIZE}}',
							],
						]
					);

				$this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_group_control(
	            Group_Control_Border::get_type(), [
	                'name' 		=> 'nav_border',
	                'selector' 	=> '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button',
	                'separator' => 'before',
	            ]
	        );

	        $this->add_control(
	            'nav_border_radius',
	            [
	                'label' 		=> esc_html__( 'Border Radius', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'nav_margin_prev',
	            [
	                'label' 		=> esc_html__( 'Margin Prev', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button.owl-prev' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'nav_margin_next',
	            [
	                'label' 		=> esc_html__( 'Margin Next', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav button.owl-next' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

	        $this->add_responsive_control(
	            'nav_margin',
	            [
	                'label' 		=> esc_html__( 'Margin', 'cryptlight' ),
	                'type' 			=> Controls_Manager::DIMENSIONS,
	                'size_units' 	=> [ 'px', '%', 'em' ],
	                'selectors' 	=> [
	                    '{{WRAPPER}} .ova-team-slider-2 .team-slider-2-wrapper.owl-carousel .owl-nav' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	                ],
	            ]
	        );

        $this->end_controls_section();
        /* End Nav Style */
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$type 		      = $settings['type'];
		$items 		= $settings['team_slider_items'];

		$data_options['items']              = $settings['item_number'];
		$data_options['slideBy']            = $settings['slides_to_scroll'];
		$data_options['margin']             = $settings['margin_items'];
		$data_options['autoplayHoverPause'] = $settings['pause_on_hover'] === 'yes' ? true : false;
		$data_options['loop']               = $settings['infinite'] === 'yes' ? true : false;
		$data_options['autoplay']           = $settings['autoplay'] === 'yes' ? true : false;
		$data_options['autoplayTimeout']    = $settings['autoplay_speed'];
		$data_options['smartSpeed']         = $settings['smartspeed'];
		$data_options['nav']                = $settings['nav_control'] === 'yes' ? true : false;
		$data_options['autoWidth']          = $settings['autoWidth'] === 'yes' ? true : false;
		$data_options['nav_left']           = $settings['nav_left'];
		$data_options['nav_right']          = $settings['nav_right'];

		 ?>

		 	<?php if ( $items && is_array( $items ) ): ?>
		 	<div class="ova-team-slider-2 ova-team-slider-2-<?php echo esc_html( $type ); ?>">
		 		<div class="team-slider-2-wrapper owl-carousel owl-theme" data-options="<?php echo esc_attr( json_encode( $data_options ) ); ?>">
		 			<?php foreach ( $items as $key => $item ): 
		 				$link       = $item['link'];
		 				$nofollow   = ( isset( $link['nofollow'] ) && $link['nofollow'] ) ? ' rel="nofollow"' : '';
						$target     = ( isset( $link['is_external'] ) && $link['is_external'] !== '' ) ? ' target="_blank"' : '';
		 				$avatar_url = $item['avatar']['url'];
		 				$alt 		= isset( $item['avatar']['alt'] ) ? $item['avatar']['alt'] : esc_html__( 'Avatar', 'cryptlight' );
		 			?>
		 				<div class="items">

		 					<?php if ( !empty($link['url'])) : ?>	
							<a href="<?php echo esc_url( $link['url'] ); ?> "  <?php echo esc_attr( $target ); ?> <?php echo esc_attr( $nofollow ); ?>>
						    <?php endif; ?>
			 					<div class="avatar <?php if( $key % 2 == 0 ) echo "low"; ?>">
			 						<div class="frame"></div>
			 						<img src="<?php echo esc_url( $avatar_url ); ?>" alt="<?php echo esc_html( $alt ); ?>">
			 					</div>
			 				<?php if ( !empty($link['url']) ) : ?>
						        </a>
					        <?php endif; ?>

					        <?php if( $type === "v2") echo "<div class='info'>" ;?>

			 					<!-- Name -->
			 					<?php if ( $item['name'] ): ?>
			 						<h3 class="name"><?php echo esc_html( $item['name'] ); ?></h3>
			 					<?php endif; ?>

			 					<!-- Job -->
			 					<?php if ( $item['job'] ): ?>
			 						<p class="job"><?php echo esc_html( $item['job'] ); ?></p>
		 						<?php endif; ?>

                            <?php if( $type === "v2") echo "</div>" ;?>

		 				</div>
		 			<?php endforeach; ?>
		 		</div>
		 	</div>
		<?php endif; ?>

		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Team_Slider_2() );