<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cryptlight_Elementor_Text_Marquee_2 extends Widget_Base {

	public function get_name() {
		return 'cryptlight_elementor_text_marquee_2';
	}

	public function get_title() {
		return esc_html__( 'Text Marquee 2', 'cryptlight' );
	}

	public function get_icon() {
		return 'eicon-animation-text';
	}

	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'cryptlight' ),
			]
		);	

			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'text',
				[
					'label' => esc_html__( 'Text', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'default' => esc_html__( 'Your Text' , 'cryptlight' ),
					'show_label' => true,
				]
			);

			$repeater->add_control(
				'show_image',
				[
					'label' 		=> esc_html__( 'Show Image', 'cryptlight' ),
					'type' 			=> \Elementor\Controls_Manager::SWITCHER,
					'label_on' 		=> esc_html__( 'Show', 'cryptlight' ),
					'label_off' 	=> esc_html__( 'Hide', 'cryptlight' ),
					'return_value' 	=> 'yes',
					'default' 		=> 'yes',
				],
			);

			$repeater->add_control(
				'image',
				[
					'label' => esc_html__( 'Choose Image', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
					'condition' => [
						'show_image' => 'yes',
					],
				]
			);

			$repeater->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'typography_content',
					'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
				]
			);

			$repeater->add_control(
				'color',
				[
					'label' => esc_html__( 'Color', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} {{CURRENT_ITEM}}' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'items',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'text' => esc_html__( 'Marketing','cryptlight' ),
						],
						[
							'text' => esc_html__( 'SEO', 'cryptlight' ),
						],
						[
							'text' => esc_html__( 'Dancing', 'cryptlight' ),
						],
						[
							'text' => esc_html__( 'Convention', 'cryptlight' ),
						],
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'image_section_style',
			[
				'label' => esc_html__( 'Image', 'cryptlight' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'image_size',
				[
					'label' => esc_html__( 'Size', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-text-marquee-2 .content .image img' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'image_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'cryptlight' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
					   '{{WRAPPER}} .ova-text-marquee-2 .content .image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'image_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
					   '{{WRAPPER}} .ova-text-marquee-2 .content .image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'line_decoration_section_style',
			[
				'label' => esc_html__( 'Line Decoration', 'cryptlight' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		    $this->add_control(
				'line_decoration_color',
				[
					'label' => esc_html__( 'Color', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-text-marquee-2 .content .image .line-decoration' => 'background-color: {{VALUE}}',
					],
				]
			);

			$this->add_responsive_control(
				'line_decoration_width',
				[
					'label' => esc_html__( 'Width', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 200,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-text-marquee-2 .content .image .line-decoration' => 'width: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .ova-text-marquee-2 .content .image' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'line_decoration_height',
				[
					'label' => esc_html__( 'Height', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-text-marquee-2 .content .image .line-decoration' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'line_decoration_position_bottom',
				[
					'label' => esc_html__( 'Position Bottom', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 100,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-text-marquee-2 .content .image .line-decoration' => 'bottom: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' 		=> 'line_decoration_border',
					'label' 	=> esc_html__( 'Border', 'cryptlight' ),
					'selector' 	=> '{{WRAPPER}} .ova-text-marquee-2 .content .image .line-decoration',
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'text_section_style',
			[
				'label' => esc_html__( 'Text', 'cryptlight' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'content_typography',
					'selector' => '{{WRAPPER}} .ova-text-marquee-2 .content .text',
				]
			);


			$this->add_group_control(
				\Elementor\Group_Control_Text_Stroke::get_type(),
				[
					'name' => 'text_stroke',
					'selector' => '{{WRAPPER}} .ova-text-marquee-2 .content .text',
				]
			);

			$this->add_control(
				'text_color',
				[
					'label' => esc_html__( 'Text Color', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-text-marquee-2 .content .text' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'time_duration',
				[
					'label' => esc_html__( 'Time Duration', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'normal',
					'options' => [
						'slow' => esc_html__( 'Slow', 'cryptlight' ),
						'normal' => esc_html__( 'Normal', 'cryptlight' ),
						'fast' => esc_html__( 'Fast', 'cryptlight' ),
					],
				]
			);

			$this->add_control(
				'direction',
				[
					'label' => esc_html__( 'Direction', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'rtl',
					'options' => [
						'ltr' => esc_html__( 'Left to Right', 'cryptlight' ),
						'rtl' => esc_html__( 'Right to Left', 'cryptlight' ),
					],
				]
			);

		$this->end_controls_section();
	}

	// Render Template Here
	protected function render() {
		$settings = $this->get_settings();

		$items 		    = $settings['items'];
		$direction 		= $settings['direction'];
		$time_duration  = $settings['time_duration'];

		?>

			<div class="ova-text-marquee-2 duration-<?php echo esc_attr($time_duration); ?> direction-<?php echo esc_attr($direction); ?>">

				<?php if( is_array($items) && $items ) : ?>

					<div class="content content-wrapper">

					  	<?php foreach($items as $item) { 
							$item_id  		= 'elementor-repeater-item-' . $item['_id'];
							$text  	  		=  $item['text'];
							$show_image     =  $item['show_image'];
							$image    		=  $item['image']['url'];
						?>

							<span class="text <?php echo esc_attr( $item_id ); ?> ">
								<?php echo esc_html( $text ) . ' '; ?>	
							</span>

							<span class="image">
								<?php if( $image != '' && $show_image == 'yes' ) { ?>
									<img src="<?php echo esc_attr($image); ?>" alt="<?php esc_attr_e('Marquee','cryptlight');?>">
								<?php } ?>
								<span class="line-decoration "></span>
							</span>

						<?php } ?>													

					</div>

					<div class="spacing"></div>

					<div class="content content-wrapper-2">

					  	<?php foreach($items as $item) { 
							$item_id  		= 'elementor-repeater-item-' . $item['_id'];
							$text  	  		=  $item['text'];
							$show_image     =  $item['show_image'];
							$image    		=  $item['image']['url'];
						?>

							<span class="text <?php echo esc_attr( $item_id ); ?> ">
								<?php echo esc_html( $text ) . ' '; ?>	
							</span>

							<span class="image">
								<?php if( $image != '' && $show_image == 'yes' ) { ?>
									<img src="<?php echo esc_attr($image); ?>" alt="<?php esc_attr_e('Marquee','cryptlight');?>">
								<?php } ?>
								<span class="line-decoration"></span>
							</span>

						<?php } ?>													

					</div>
					
				<?php endif; ?>

			</div>

		<?php
	}
}
$widgets_manager->register( new Cryptlight_Elementor_Text_Marquee_2() );