<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class cryptlight_Elementor_Text_Marquee_3 extends Widget_Base {

	public function get_name() {
		return 'cryptlight_elementor_text_marquee_3';
	}

	public function get_title() {
		return esc_html__( 'Text Marquee 3', 'cryptlight' );
	}

	public function get_icon() {
		return 'eicon-animation-text';
	}

	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ '' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'cryptlight' ),
			]
		);	
			
			$repeater = new \Elementor\Repeater();

			$repeater->add_control(
				'text',
				[
					'label' => esc_html__( 'Text', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::TEXTAREA,
					'default' => esc_html__( 'AI image generator' , 'cryptlight' ),
					'show_label' => true,
				]
			);

			$repeater->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'typography_content',
					'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
				]
			);
			
			$repeater->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'background_current_item',
					'types' => [ 'classic', 'gradient' ],
					'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
				]
			);

			$repeater->add_group_control(
				\Elementor\Group_Control_Text_Stroke::get_type(),
				[
					'name' => 'text_stroke_item',
					'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}',
				]
			);

			$this->add_control(
				'items',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::REPEATER,
					'fields' => $repeater->get_controls(),
					'default' => [
						[
							'text' => esc_html__( 'AI image generator', 'cryptlight' ),
						],
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'text_section_style',
			[
				'label' => esc_html__( 'Text', 'cryptlight' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'content_typography',
					'selector' => '{{WRAPPER}} .ova-text-marquee-3 .content .text',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'background_text',
					'types' => [ 'classic', 'gradient' ],
					'selector' => '{{WRAPPER}} .ova-text-marquee-3 .content .text',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Text_Stroke::get_type(),
				[
					'name' => 'text_stroke',
					'selector' => '{{WRAPPER}} .ova-text-marquee-3 .content .text',
				]
			);

			$this->add_responsive_control(
				'space_between',
				[
					'label' => esc_html__( 'Space Between', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%', 'em', 'rem' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-text-marquee-3 .spacing' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'time_duration',
				[
					'label' => esc_html__( 'Time Duration', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'normal',
					'options' => [
						'none' => esc_html__( 'None', 'cryptlight' ),
						'normal' => esc_html__( 'Normal', 'cryptlight' ),
						'slow' => esc_html__( 'Slow', 'cryptlight' ),
						'fast' => esc_html__( 'Fast', 'cryptlight' ),
					],
				]
			);

		$this->end_controls_section();
	}

	// Render Template Here
	protected function render() {

		$settings	= $this->get_settings();
		$items 		= $settings['items'];

		$time_duration = $settings['time_duration'];

		?>

			<div class="ova-text-marquee-3 duration-<?php echo esc_attr($time_duration); ?>">

				<?php if( is_array($items) && $items ) : ?>

					<div class="content content-wrapper">

					  	<?php foreach($items as $item) { 
							$item_id  = 'elementor-repeater-item-' . $item['_id'];
							$text  	  =  $item['text'];
						?>
                            <?php if( !empty($background_clip_text) ) : ?>
								<span class="text <?php echo esc_attr( $item_id ); ?>">
									<?php echo esc_html( $text ) . ' '; ?>	
								</span>
							<?php else : ?>
								<span class="text text-color <?php echo esc_attr( $item_id ); ?>">
									<?php echo esc_html( $text ) . ' '; ?>	
								</span>
							<?php endif; ?>
						<?php } ?>													

					</div>

					<div class="spacing"></div>

					<div class="content content-wrapper-2">

					  	<?php foreach($items as $item) { 
							$item_id  = 'elementor-repeater-item-' . $item['_id'];
							$text  	  =  $item['text'];
						?>

							<?php if( !empty($background_clip_text) ) : ?>
								<span class="text <?php echo esc_attr( $item_id ); ?>" style="background-image: url('<?php echo esc_url( $background_clip_text ); ?>');">
									<?php echo esc_html( $text ) . ' '; ?>	
								</span>
							<?php else : ?>
								<span class="text text-color <?php echo esc_attr( $item_id ); ?>">
									<?php echo esc_html( $text ) . ' '; ?>	
								</span>
							<?php endif; ?>

						<?php } ?>											

					</div>

				<?php endif; ?>

			</div>

		<?php
	}
}

$widgets_manager->register( new Cryptlight_Elementor_Text_Marquee_3() );