<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Border;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Cryptlight_Elementor_Vertical_Slider extends Widget_Base {

	public function get_name() {
		return 'cryptlight_elementor_vertical_slider';
	}

	public function get_title() {
		return esc_html__( 'Ova Vertical Slider', 'cryptlight' );
	}

	public function get_icon() {
		return 'eicon-slider-vertical';
	}

	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		wp_enqueue_style( 'animate', CRYPTLIGHT_URI.'/assets/libs/animate/animate.css');
		return [ 'cryptlight-elementor-vertical-slider' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {
		/* Content */
		$this->start_controls_section(
				'section_content',
				[
					'label' => esc_html__( 'Content', 'cryptlight' ),
				]
			);

			$repeater = new \Elementor\Repeater();

				$repeater->add_control(
					'image',
					[
						'label'   => esc_html__( 'Image', 'cryptlight' ),
						'type'    => \Elementor\Controls_Manager::MEDIA,
						'default' => [
							'url' => Utils::get_placeholder_image_src(),
						],
					]
				);

				$repeater->add_control(
					'subtitle',
					[
						'label' => esc_html__( 'Subtitle', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						'default' => esc_html__( 'Optimize Your Business Growth', 'cryptlight' ),
						'placeholder' => esc_html__( 'Type your subtitle here', 'cryptlight' ),
						'label_block' => true,
					]
				);

				$repeater->add_control(
					'title',
					[
						'label' => esc_html__( 'Title', 'cryptlight' ),
						'type' => \Elementor\Controls_Manager::TEXTAREA,
						'rows' => 5,
						'default' => esc_html__( 'Step 1: Select "Chatsonic"&#13;&#10;from the Writesonic&#13;&#10;dashboard.', 'cryptlight' ),
						'placeholder' => esc_html__( 'Type your title here', 'cryptlight' ),
					]
				);

				$repeater->add_control(
					'description',
					[
						'label'   => esc_html__( 'Description ', 'cryptlight' ),
						'type'    => \Elementor\Controls_Manager::TEXTAREA,
						'rows' => 10,
						'default' => esc_html__( 'Ready to join the AI chatbot revolution? Let’s get started!Log into your Writesonic account. Sign up for free today if you haven’t created an account yet. Next, go to the Writesonic Library and select “Chatsonic” from the list of content templates.', 'cryptlight' ),
					]
				);

				$this->add_control(
					'tab_item',
					[
						'label'       => esc_html__( 'Items description', 'cryptlight' ),
						'type'        => \Elementor\Controls_Manager::REPEATER,
						'fields'      => $repeater->get_controls(),
						'default' => [
							[
								'title' => esc_html__('Step 1: Select "Chatsonic"&#13;&#10;from the Writesonic&#13;&#10;dashboard.', 'cryptlight'),
							],
							[
								'title' => esc_html__('Step 2: Select "Chatsonic"&#13;&#10;from the Writesonic&#13;&#10;dashboard.', 'cryptlight'),
							],
							[
								'title' => esc_html__('Step 3: Select "Chatsonic"&#13;&#10;from the Writesonic&#13;&#10;dashboard.', 'cryptlight'),
							],
						],
						'title_field' => '{{{ title }}}',
					]
				);

		$this->end_controls_section();

		/*****************  END SECTION CONTENT ******************/


		/*****************************************************************
						START SECTION ADDITIONAL
		******************************************************************/

		$this->start_controls_section(
				'section_additional_options',
				[
					'label' => esc_html__( 'Additional Options', 'cryptlight' ),
				]
			);

			$this->add_control(
				'margin_items',
				[
					'label'   => esc_html__( 'Margin Right Items', 'cryptlight' ),
					'type'    => \Elementor\Controls_Manager::NUMBER,
					'default' => 30,
				]
				
			);

			$this->add_control(
				'item_number',
				[
					'label'       => esc_html__( 'Item Number', 'cryptlight' ),
					'type'        => \Elementor\Controls_Manager::NUMBER,
					'description' => esc_html__( 'Number Item', 'cryptlight' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'slides_to_scroll',
				[
					'label'       => esc_html__( 'Slides to Scroll', 'cryptlight' ),
					'type'        => \Elementor\Controls_Manager::NUMBER,
					'description' => esc_html__( 'Set how many slides are scrolled per swipe.', 'cryptlight' ),
					'default'     => 1,
				]
			);

			$this->add_control(
				'pause_on_hover',
				[
					'label'   => esc_html__( 'Pause on Hover', 'cryptlight' ),
					'type'    => \Elementor\Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'infinite',
				[
					'label'   => esc_html__( 'Infinite Loop', 'cryptlight' ),
					'type'    => \Elementor\Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay',
				[
					'label'   => esc_html__( 'Autoplay', 'cryptlight' ),
					'type'    => \Elementor\Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'autoplay_speed',
				[
					'label'     => esc_html__( 'Autoplay Speed', 'cryptlight' ),
					'type'      => \Elementor\Controls_Manager::NUMBER,
					'default'   => 3000,
					'step'      => 500,
					'condition' => [
						'autoplay' => 'yes',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'smartspeed',
				[
					'label'   => esc_html__( 'Smart Speed', 'cryptlight' ),
					'type'    => \Elementor\Controls_Manager::NUMBER,
					'default' => 1000,
				]
			);

			$this->add_control(
				'dot_control',
				[
					'label'   => esc_html__( 'Show Dots', 'cryptlight' ),
					'type'    => \Elementor\Controls_Manager::SWITCHER,
					'default' => 'yes',
					'options' => [
						'yes' => esc_html__( 'Yes', 'cryptlight' ),
						'no'  => esc_html__( 'No', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

		$this->end_controls_section();

		/****************************  END SECTION ADDITIONAL *********************/
		/* Items */
		$this->start_controls_section(
				'section_general',
				[
					'label' => esc_html__( 'Items', 'cryptlight' ),
					'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'items_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .card' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'items_border',
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .owl-stage-outer',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'items_box_shadow',
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .owl-stage-outer',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'items_background',
					'types' => [ 'classic', 'gradient', 'video' ],
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .card',
				]
			);

		$this->end_controls_section();

		/* Number */
		$this->start_controls_section(
				'number_style_section',
				[
					'label' => esc_html__( 'Number', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'number_typography',
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .number',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Background::get_type(),
				[
					'name' => 'number_background',
					'types' => [ 'classic', 'gradient', 'video' ],
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .number',
				]
			);

		$this->end_controls_section();

		/* Subtitle */
		$this->start_controls_section(
				'subtitle_style_section',
				[
					'label' => esc_html__( 'Subtitle', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'subtitle_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'subtitle_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .subtitle' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'subtitle_border',
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .subtitle',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'subtitle_typography',
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .subtitle',
				]
			);

			$this->add_control(
				'subtitle_color',
				[
					'label' => esc_html__( 'Color', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .subtitle' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

		/* Title */
		$this->start_controls_section(
				'title_style_section',
				[
					'label' => esc_html__( 'Title', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'title_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'title_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'title_typography',
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .title',
				]
			);

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Color', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .title' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

		/* Description */
		$this->start_controls_section(
				'desc_style_section',
				[
					'label' => esc_html__( 'Description', 'cryptlight' ),
					'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'desc_margin',
				[
					'label' => esc_html__( 'Margin', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'desc_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'desc_typography',
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .description',
				]
			);

			$this->add_control(
				'desc_color',
				[
					'label' => esc_html__( 'Color', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .card .wrapper .description' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();
		
		/* Dots */
		$this->start_controls_section(
				'dots_section_styles',
				[
					'label' => esc_html__( 'Dots', 'cryptlight' ),
					'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
				]
			);

			$this->add_responsive_control(
				'dots_padding',
				[
					'label' => esc_html__( 'Padding', 'cryptlight' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .owl-dots' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'dots_border',
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .owl-dots',
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'dots_box_shadow',
					'selector' => '{{WRAPPER}} .ova-vertival-slider .vertival-slider .owl-dots',
				]
			);

			$this->add_control(
				'dot_bg',
				[
					'label'     => esc_html__( 'Background', 'cryptlight' ),
					'type'      => \Elementor\Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-vertival-slider .vertival-slider .owl-dots' => 'background : {{VALUE}};',
					],
				]
			);

			$this->start_controls_tabs(
					'dots_style_tabs'
				);

				$this->start_controls_tab(
						'dots_style_normal_tab',
						[
							'label' => esc_html__( 'Normal', 'cryptlight' ),
						]
					);

				$this->add_control(
					'dot_color',
					[
						'label'     => esc_html__( 'Color', 'cryptlight' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-vertival-slider .vertival-slider .owl-dots .owl-dot span' => 'background : {{VALUE}};',
						],
					]
				);

				$this->end_controls_tab();

				$this->start_controls_tab(
						'dots_style_active_tab',
						[
							'label' => esc_html__( 'Active', 'cryptlight' ),
						]
					);

				$this->add_control(
					'dot_active_color',
					[
						'label'     => esc_html__( 'Color', 'cryptlight' ),
						'type'      => \Elementor\Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .ova-vertival-slider .vertival-slider .owl-dots .owl-dot.active span' => 'background : {{VALUE}};',
						],
					]
				);

				$this->end_controls_tab();

			$this->end_controls_tabs();

		$this->end_controls_section();
	}

	// Render Template Here
	protected function render() {
		$settings 	= $this->get_settings();
		$tab_item 	= $settings['tab_item'];
		
		$data_options['items']              = $settings['item_number'];
		$data_options['slideBy']            = $settings['slides_to_scroll'];
		$data_options['margin']             = $settings['margin_items'];
		$data_options['autoplayHoverPause'] = $settings['pause_on_hover'] === 'yes' ? true : false;
		$data_options['loop']               = $settings['infinite'] === 'yes' ? true : false;
		$data_options['autoplay']           = $settings['autoplay'] === 'yes' ? true : false;
		$data_options['autoplayTimeout']    = $settings['autoplay_speed'];
		$data_options['smartSpeed']         = $settings['smartspeed'];
		$data_options['dots']               = $settings['dot_control'] === 'yes' ? true : false;
		$data_options['rtl']				= is_rtl() ? true: false;
		?>
		<section class="ova-vertival-slider">
			<div class="vertival-slider owl-carousel owl-theme " data-options="<?php echo esc_attr(json_encode($data_options)) ?>">
				<?php if ( ! empty( $tab_item ) ) : foreach( $tab_item as $key => $item ): ?>
					<?php
						$image_url 		= $item['image']['url'];
						$image_id 		= $item['image']['id'];
						$image_alt 		= $item['title'];
						if ( $image_id ) {
							$image_alt = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
							if ( ! $image_alt ) {
								$image_alt = get_the_title( $image_id );
							}
						}
						$subtitle 		= $item['subtitle'];
						$title 			= $item['title'];
						$description 	= $item['description'];
						$item_number 	= ( $key + 1 ) < 10 ? '0' . ( $key + 1 ) : ( $key + 1 );
					?>
					<div class="item">
						<div class="card">
							<span class="number"><?php echo esc_html( $item_number ); ?></span>
							<div class="wrapper">
								<div class="image">
									<?php if ($image_url): ?>
											<img src="<?php echo esc_url( $image_url ); ?>"
											alt="<?php echo esc_attr( $image_alt ); ?>">
									<?php endif; ?>
								</div>
								<div class="content">
									<?php if ( $subtitle ): ?>
										<p class="subtitle"><?php echo esc_html( $subtitle ); ?></p>
									<?php endif; ?>
									<?php if ( $title ): ?>
										<h3 class="title"><?php echo esc_html( $title ); ?></h3>
									<?php endif; ?>
									<?php if ( $description ): ?>
										<p class="description">
											<?php echo esc_html( $description ); ?>
										</p>
									<?php endif; ?>
								</div>
							</div>
						</div>
					</div>
				<?php endforeach; endif; ?>
			</div>
		</section>
		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Vertical_Slider() );