<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Cryptlight_Elementor_Video_Popup extends Widget_Base {

	
	public function get_name() {
		return 'cryptlight_elementor_video_popup';
	}

	
	public function get_title() {
		return esc_html__( 'Video Popup', 'cryptlight' );
	}

	
	public function get_icon() {
		return 'eicon-youtube';
	}

	
	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		return [ 'cryptlight-elementor-video-popup' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'cryptlight' ),
			]
		);	
			
			// Add Class control

		    $this->add_control(
				'icon',
				[
					'label' 	=> esc_html__( 'Icon', 'cryptlight' ),
					'type' 		=> Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'fas fa-play',
						'library' 	=> 'all',
					],
				]
			);

			$this->add_control(
				'text',
				[
					'label' 	=> esc_html__( 'Text', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
				]
			);

			$this->add_control(
				'url_video',
				[
					'label' 		=> esc_html__( 'URL Video', 'cryptlight' ),
					'type' 			=> Controls_Manager::TEXT,
					'placeholder' 	=> esc_html__( 'Enter your URL', 'cryptlight' ) . ' (YouTube)',
					'description' 	=> esc_html__( 'YouTube URL', 'cryptlight' ),
					'default' 		=> 'https://www.youtube.com/watch?v=XHOmBV4js_E',
				]
			);

			$this->add_control(
				'image',
				[
					'label' => esc_html__( 'Choose Image', 'cryptlight' ),
					'type' 	=> Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
				]
			);

			$this->add_control(
				'video_options',
				[
					'label' 	=> esc_html__( 'Video Options', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

			$this->add_control(
				'autoplay_video',
				[
					'label' 	=> esc_html__( 'Autoplay', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'yes',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

			$this->add_control(
				'mute_video',
				[
					'label' 	=> esc_html__( 'Mute', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'no',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

			$this->add_control(
				'loop_video',
				[
					'label' 	=> esc_html__( 'Loop', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'yes',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

			$this->add_control(
				'player_controls_video',
				[
					'label' 	=> esc_html__( 'Player Controls', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'yes',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

			$this->add_control(
				'modest_branding_video',
				[
					'label' 	=> esc_html__( 'Modest Branding', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'yes',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

			$this->add_control(
				'show_info_video',
				[
					'label' 	=> esc_html__( 'Show Info', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'no',
					'condition' => [
						'url_video!' => '',
					],
				]
			);


			$this->add_responsive_control(
				'align',
				[
					'label' => esc_html__( 'Alignment', 'cryptlight' ),
					'type' 	=> Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => esc_html__( 'Left', 'cryptlight' ),
							'icon' 	=> 'eicon-text-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'cryptlight' ),
							'icon' 	=> 'eicon-text-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'cryptlight' ),
							'icon' 	=> 'eicon-text-align-right',
						],
					],
					'default' => '',
					'selectors' => [
						'{{WRAPPER}}' => 'text-align: {{VALUE}};',
					],
					'condition' => [
						'image[url]' => '',
					]
				]
			);

		$this->end_controls_section();

		/* Begin section video style */
		$this->start_controls_section(
			'section_video_style',
			[
				'label' => esc_html__( 'Video', 'cryptlight' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'video_width',
				[
					'label' 	=> esc_html__( 'Width', 'cryptlight' ),
					'type' 		=> Controls_Manager::SLIDER,
					'default' 	=> [
						'unit' 	=> '%',
					],
					'tablet_default' => [
						'unit' => '%',
					],
					'mobile_default' => [
						'unit' => '%',
					],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' 	=> [ '%', 'px' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video-popup .ova-video-popup-container .video-content' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->start_controls_tabs(
				'style_video_tabs'
			);

				$this->start_controls_tab(
					'style_video_normal_tab',
					[
						'label' => esc_html__( 'Normal', 'cryptlight' ),
					]
				);

					$this->add_control(
			            'video_background_normal',
			            [
			                'label' 	=> esc_html__( 'Background', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video-popup .ova-video-popup-container .video-content' => 'background-color: {{VALUE}};',
			                ],
			            ]
			        );

				$this->end_controls_tab();

				$this->start_controls_tab(
					'style_video_hover_tab',
					[
						'label' => esc_html__( 'Hover', 'cryptlight' ),
					]
				);

					$this->add_control(
			            'video_background_hover',
			            [
			                'label' 	=> esc_html__( 'Background', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video-popup .ova-video-popup-container .video-content:hover' => 'background-color: {{VALUE}};',
			                ],
			            ]
			        );

			        $this->add_control(
						'video_border_color_hover',
						[
							'label' 	=> esc_html__( 'Border Color', 'cryptlight' ),
							'type' 		=> Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .ova-video-popup .ova-video-popup-container .video-content:hover' => 'border-color: {{VALUE}}',
							],
						]
					);

				$this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' 		=> 'video_border',
					'label' 	=> esc_html__( 'Border', 'cryptlight' ),
					'selector' 	=> '{{WRAPPER}} .ova-video-popup .ova-video-popup-container .video-content',
				]
			);

			$this->add_responsive_control(
				'video_border_radius',
				[
					'label' 		=> esc_html__( 'Border Radius', 'cryptlight' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video-popup .ova-video-popup-container .video-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		/* End section video style */

		/* Begin section icon style */
		$this->start_controls_section(
			'section_icon_style',
			[
				'label' => esc_html__( 'Icon', 'cryptlight' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

	        $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'icon_typography',
					'selector' 	=> '{{WRAPPER}} .ova-video-popup .ova-video-popup-container .video-content i',
				]
			);

			$this->start_controls_tabs(
				'style_icon_tabs'
			);

				$this->start_controls_tab(
					'style_icon_normal_tab',
					[
						'label' => esc_html__( 'Normal', 'cryptlight' ),
					]
				);

					$this->add_control(
			            'icon_color_normal',
			            [
			                'label' 	=> esc_html__( 'Color', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video-popup .ova-video-popup-container .video-content i' => 'color: {{VALUE}};',
			                ],
			            ]
			        );

				$this->end_controls_tab();

				$this->start_controls_tab(
					'style_icon_hover_tab',
					[
						'label' => esc_html__( 'Hover', 'cryptlight' ),
					]
				);

					$this->add_control(
			            'icon_color_hover',
			            [
			                'label' 	=> esc_html__( 'Color', 'cryptlight' ),
			                'type' 		=> Controls_Manager::COLOR,
			                'selectors' => [
			                    '{{WRAPPER}} .ova-video-popup .ova-video-popup-container .video-content:hover i' => 'color: {{VALUE}};',
			                ],
			            ]
			        );

				$this->end_controls_tab();
			$this->end_controls_tabs();

		$this->end_controls_section();
		/* End section icon style */

		/* Begin section image style */
		$this->start_controls_section(
			'section_image_style',
			[
				'label' => esc_html__( 'Image', 'cryptlight' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_responsive_control(
				'image_width',
				[
					'label' 		=> esc_html__( 'Width', 'cryptlight' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%', 'vw' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
						'vw' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-video-popup .ova-video-popup-container img' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'image_max_width',
				[
					'label' 		=> esc_html__( 'Max Width', 'cryptlight' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%', 'vw' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
						'vw' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-video-popup .ova-video-popup-container img' => 'max-width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'image_height',
				[
					'label' 		=> esc_html__( 'Height', 'cryptlight' ),
					'type' 			=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%', 'vh' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 500,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
						'vh' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-video-popup .ova-video-popup-container img' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'image_border_radius',
				[
					'label' 		=> esc_html__( 'Border Radius', 'cryptlight' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .ova-video-popup .ova-video-popup-container' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
	            'overlay_color',
	            [
	                'label' 	=> esc_html__( 'Overlay Color', 'cryptlight' ),
	                'type' 		=> Controls_Manager::COLOR,
	                'selectors' => [
	                    '{{WRAPPER}} .ova-video-popup .ova-video-popup-container:before' => 'background-color: {{VALUE}};',
	                ],
	            ]
	        );

		$this->end_controls_section();
		/* End section Image style */
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

		$icon 		= $settings['icon']['value'];
		$text 		= $settings['text'];

		$url_video 	= $settings['url_video'];
		$image_url 	= isset( $settings['image']['url'] ) ? $settings['image']['url'] : '';
		$image_alt 	= isset( $settings['image']['alt'] ) ? $settings['image']['alt'] : '';
		$class_img 	= $image_url ? ' video-image' : '';
		$autoplay 	= $settings['autoplay_video'];
		$mute 		= $settings['mute_video'];
		$loop 		= $settings['loop_video'];
		$controls 	= $settings['player_controls_video'];
		$modest 	= $settings['modest_branding_video'];
		$show_info 	= $settings['show_info_video'];

		 ?>

         <?php if ( $url_video ): ?>
			<div class="ova-video-popup">
				<div class="ova-video-popup-container">
					<?php if ( $image_url ): ?>
						<img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">
					<?php endif; ?>
					<div class="video-content video-btn<?php echo esc_attr( $class_img ); ?>" id="ova-video-popup" 
						 data-src="<?php echo esc_url( $url_video ); ?>" 
						 data-autoplay="<?php echo esc_html( $autoplay ); ?>" 
						 data-mute="<?php echo esc_html( $mute ); ?>" 
						 data-loop="<?php echo esc_html( $loop ); ?>" 
						 data-controls="<?php echo esc_html( $controls ); ?>" 
						 data-modest="<?php echo esc_html( $modest ); ?>" 
						 data-show_info="<?php echo esc_html( $show_info ); ?>">
						<?php if( !empty($icon)) { ?>
							<i class="<?php echo esc_html( $icon ); ?>"></i>
						<?php } ?>
						<?php if( !empty($text)) { ?>
							<span class="text-play">
								<?php echo esc_html($text);?>
							</span>
						<?php } ?>
					</div>
				</div>
				<div class="modal-container">
					<div class="modal">
						<i class="ovaicon-cancel"></i>
						<iframe class="modal-video" allow="autoplay"></iframe>
					</div>
				</div>
			</div>
		 	
		<?php
	    endif;
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Video_Popup() );