<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use Elementor\Utils;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class Cryptlight_Elementor_Video extends Widget_Base {

	
	public function get_name() {
		return 'cryptlight_elementor_video';
	}

	
	public function get_title() {
		return esc_html__( 'Video', 'cryptlight' );
	}

	
	public function get_icon() {
		return 'eicon-video-camera';
	}

	
	public function get_categories() {
		return [ 'cryptlight' ];
	}

	public function get_script_depends() {
		wp_enqueue_style( 'cryptlight-elementor-video', get_theme_file_uri('/assets/libs/video/video.min.css') );
		wp_enqueue_script( 'cryptlight-elementor-videojs', get_theme_file_uri('/assets/libs/video/video.min.js'), array('jquery'), false, true );
		wp_enqueue_script( 'cryptlight-elementor-youtube', get_theme_file_uri('/assets/libs/video/youtube.min.js'), array('jquery'), false, true );
		return [ 'cryptlight-elementor-video' ];
	}
	
	// Add Your Controll In This Function
	protected function register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'cryptlight' ),
			]
		);	
				
			// Add Class control

		    $this->add_control(
				'id_video',
				[
					'label' 	=> esc_html__( 'ID Video', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'my-video', 'cryptlight' ),
					'description' 	=> esc_html__( 'Unique id in each video element', 'cryptlight' ),
				]
			);

			$this->add_control(
				'video_type',
				[
					'label' => esc_html__( 'Source', 'cryptlight' ),
					'type' => Controls_Manager::SELECT,
					'default' => 'custom_url',
					'options' => [
						'youtube' => esc_html__( 'YouTube', 'cryptlight' ),
						'custom_url' => esc_html__( 'Custom URL', 'cryptlight' ),
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'youtube_url',
				[
					'label' => esc_html__( 'Link Youtube', 'cryptlight' ),
					'type' => Controls_Manager::TEXT,
					'placeholder' => esc_html__( 'Enter your URL', 'cryptlight' ) . ' (YouTube)',
					'default' => 'https://www.youtube.com/watch?v=XHOmBV4js_E',
					'condition' => [
						'video_type' => 'youtube',
					],
					'frontend_available' => true,
				]
			);

			$this->add_control(
				'url_video',
				[
					'label' 		=> esc_html__( 'URL Video', 'cryptlight' ),
					'type' 			=> Controls_Manager::TEXT,
					'placeholder' 	=> esc_html__( 'Enter your URL', 'cryptlight' ),
					'description' 	=> esc_html__( 'URL Video', 'cryptlight' ),
					'default' 		=> 'https://storage.googleapis.com/media-session/caminandes/short.mp4#t=80',
					'condition' => [
						'video_type' => 'custom_url',
					],
				]
			);

			$this->add_control(
				'video_overlay',
				[
					'label' 	=> esc_html__( 'Video Overlay', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before',
				]
			);

			$this->add_control(
				'show_video_overlay',
				[
					'label' 	=> esc_html__( 'Overlay', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'yes',
				]
			);

			$this->add_control(
				'image',
				[
					'label' => esc_html__( 'Choose Image Overlay', 'cryptlight' ),
					'type' 	=> Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
					'condition' => [
						'show_video_overlay' => 'yes',
					],
				]
			);

			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'cryptlight' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__( 'Dolor tempor mauris.', 'cryptlight' ),
					'condition' => [
						'show_video_overlay' => 'yes',
					],
				]
			);

			$this->add_control(
				'icon',
				[
					'label' 	=> esc_html__( 'Icon', 'cryptlight' ),
					'type' 		=> Controls_Manager::ICONS,
					'default' 	=> [
						'value' 	=> 'fas fa-play',
						'library' 	=> 'all',
					],
					'condition' => [
						'show_video_overlay' => 'yes',
					],
				]
			);

			$this->add_control(
				'video_options',
				[
					'label' 	=> esc_html__( 'Video Options', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

			$this->add_control(
				'autoplay_video',
				[
					'label' 	=> esc_html__( 'Autoplay', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'no',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

			$this->add_control(
				'mute_video',
				[
					'label' 	=> esc_html__( 'Mute', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'no',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

			$this->add_control(
				'loop_video',
				[
					'label' 	=> esc_html__( 'Loop', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'yes',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

			$this->add_control(
				'player_controls_video',
				[
					'label' 	=> esc_html__( 'Player Controls', 'cryptlight' ),
					'type' 		=> Controls_Manager::SWITCHER,
					'label_on' 	=> esc_html__( 'Yes', 'cryptlight' ),
					'label_off' => esc_html__( 'No', 'cryptlight' ),
					'default' 	=> 'yes',
					'condition' => [
						'url_video!' => '',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_overlay',
			[
				'label' 	=> esc_html__( 'Overlay', 'cryptlight' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_control(
				'heading_title',
				[
					'label' 	=> esc_html__( 'Title', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
				]
			);

		    $this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'selector' 	=> '{{WRAPPER}} .ova-video .ova-video-container .overlay-video .overlay-video-wrapper .title',
				]
			);

			$this->add_control(
				'color_title',
				[
					'label' 	=> esc_html__( 'Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-video .ova-video-container .overlay-video .overlay-video-wrapper .title' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'color_title_hover',
				[
					'label' 	=> esc_html__( 'Color Hover', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-video .ova-video-container .overlay-video .overlay-video-wrapper:hover .title' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'heading_icon',
				[
					'label' 	=> esc_html__( 'Icon', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before'
				]
			);

			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'icon_typography',
					'selector' 	=> '{{WRAPPER}} .ova-video .ova-video-container .overlay-video .overlay-video-wrapper .play-icon i',
				]
			);


			$this->add_control(
				'color_icon',
				[
					'label' => esc_html__( 'Color', 'cryptlight' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-video .ova-video-container .overlay-video .overlay-video-wrapper .play-icon i' => 'color : {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'bgcolor_icon',
				[
					'label' 	=> esc_html__( 'Background Color', 'cryptlight' ),
					'type' 		=> Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ova-video .ova-video-container .overlay-video .overlay-video-wrapper .play-icon' => 'background-color : {{VALUE}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_opacity',
				[
					'label' => esc_html__( 'Opacity', 'cryptlight' ),
					'type' 	=> Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' 	=> 0,
							'max' 	=> 1,
							'step' 	=> 0.1,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-video .ova-video-container .overlay-video .overlay-video-wrapper .play-icon' => 'opacity: {{SIZE}};',
					],
				]
			);

			$this->add_responsive_control(
				'icon_position_top',
				[
					'label' => esc_html__( 'Top Position', 'cryptlight' ),
					'type' 	=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%' ],
					'default' => [
						'unit' => '%',
					],
					'range' => [
						'%' => [
							'min' 	=> 0,
							'max' 	=> 100,
							'step' 	=> 5,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-video .ova-video-container .overlay-video .overlay-video-wrapper .play-icon' => 'TOP: {{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_video',
			[
				'label' 	=> esc_html__( 'Video', 'cryptlight' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

		    $this->add_responsive_control(
				'video_height',
				[
					'label' => esc_html__( 'Height', 'cryptlight' ),
					'type' 	=> Controls_Manager::SLIDER,
					'size_units' 	=> [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' 	=> 0,
							'max' 	=> 1000,
							'step' 	=> 5,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-video .ova-video-container .video-js' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'heading_controls_player',
				[
					'label' 	=> esc_html__( 'Control', 'cryptlight' ),
					'type' 		=> Controls_Manager::HEADING,
					'separator' => 'before'
				]
			);

			$this->add_responsive_control(
				'controls_bar_width',
				[
					'label' => esc_html__( 'Bar Width', 'cryptlight' ),
					'type' 	=> Controls_Manager::SLIDER,
					'size_units' 	=> ['px', '%' ],
					'default' => [
						'unit' => '%',
					],
					'range' => [
						'%' => [
							'min' 	=> 0,
							'max' 	=> 100,
							'step' 	=> 5,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .ova-video .ova-video-container .video-js .vjs-control-bar' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_section();
		
	}

	// Render Template Here
	protected function render() {

		$settings = $this->get_settings();

        
        $id_video    = $settings['id_video'];
        $video_type  = $settings['video_type'];
        $url_video   = isset( $settings['url_video'] ) ? $settings['url_video'] : '' ;
        $youtube_url = isset( $settings['youtube_url'] ) ? $settings['youtube_url'] : '';

        //get overlay
        $show_video_ovelay  =  $settings['show_video_overlay'];

		$icon 		= isset( $settings['icon']['value'] ) ? $settings['icon']['value'] : '';
		$title      = isset( $settings['title'] ) ? $settings['title'] : '';
		$image_url 	= isset( $settings['image']['url'] ) ? $settings['image']['url'] : '';

		// video option
		$autoplay 	= $settings['autoplay_video'] === 'yes' ? 'autoplay' : '';
		$mute 		= $settings['mute_video'] === 'yes' ? 'muted' : '';
		$loop 		= $settings['loop_video'] === 'yes' ? 'loop' : '';
		$controls 	= $settings['player_controls_video'] === 'yes' ? 'controls' : '';

		 ?>
            
        <?php if ( $url_video || $youtube_url ): ?>
			<div class="ova-video" data-id_video="<?php echo esc_attr( $id_video ); ?>">

				<div class="ova-video-container">

					<video
					    id="<?php echo esc_attr( $id_video ); ?>"
					    class="video-js vjs-theme-city"
					    <?php echo esc_html( $controls ); ?>
					    preload="auto"
					    poster="<?php echo esc_url( $image_url ); ?>"
                        
					    <?php if ($video_type === 'youtube') : ?>
					    data-setup='{ "techOrder": ["youtube"], "sources": [{ "type": "video/youtube", "src": "<?php echo esc_attr( $youtube_url ); ?>"}], "youtube": { "ytControls": 2 } }'
					    <?php endif; ?>

					    <?php echo esc_html( $autoplay ); ?>
					    <?php echo esc_html( $mute ); ?>
					    <?php echo esc_html( $loop ); ?>
					  >
					    <?php if ($video_type === 'custom_url') : ?>
					        <source src="<?php echo esc_url( $url_video ); ?>" type="video/mp4">
                        <?php endif; ?>

                        <!-- browser no javascript -->
					    <p class="vjs-no-js">
					    	<?php echo esc_html_e('To view this video please enable JavaScript, and consider upgrading to a
					            web browser that','cryptlight');
					        ?>
					    </p>
					  </video>
			        
                   
					<!-- ova video overlay -->
					<?php if( $show_video_ovelay === 'yes') : ?>
						<div class="overlay-video">

							<div class="overlay-video-wrapper">
								<?php if ( ! empty ( $title ) ): ?>
									<div class="title">
										<?php echo esc_html( $title ); ?>
									</div>
								<?php endif; ?>

								<div class="play-icon">
									<i class="<?php echo esc_html( $icon ); ?>"></i>
								</div>
							</div>
							
						</div>
                    <?php endif;?>
                    <!-- end ova video overlay -->

				</div>

			</div>

		<?php endif; ?>
		 	
		<?php
	}

	
}
$widgets_manager->register( new Cryptlight_Elementor_Video() );